@@ -149,6 +149,7 @@ wxWindow* wxGetTopLevelParent(wxWindow *win)
 #if wxCHECK_VERSION(2, 8, 0)
 #ifdef __WXGTK20__
 #if  wxCHECK_VERSION(2, 9, 0)
+#include <gtk/gtk.h>
 #include <wx/gtk/private/win_gtk.h>
 #else
 #include <wx/gtk/win_gtk.h>
@@ -159,15 +160,27 @@ wxWindow* wxGetTopLevelParent(wxWindow *win)
 #else
 #include <wx/gtk/win_gtk.h>
 #endif
+
 #if  wxCHECK_VERSION(2, 9, 0)
-#define piz(wxwin) WX_PIZZA((wxwin)->m_wxwindow)
-#define GetXWindow(wxwin) (wxwin)->m_wxwindow ? \
-	GDK_WINDOW_XWINDOW(((GtkWidget*)piz(wxwin))->window) : \
-	GDK_WINDOW_XWINDOW((wxwin)->m_widget->window)
+/*
+Window GetXWindow(wxWindow* win) {
+	GtkWidget* widget = win->GetHandle();
+	gtk_widget_realize(widget);
+	Display* display = GDK_WINDOW_XDISPLAY(widget->window);
+	Window wid = GDK_WINDOW_XWINDOW(widget->window);
+	return wid;
+}
+*/
+//#define GetXWindow(wxwin) GtkWidget* widget = output->GetHandle();\ GDK_WINDOW_XID(win)
+
+//#define piz(wxwin) WX_PIZZA((wxwin)->m_wxwindow)
+//#define GetXWindow(wxwin) (wxwin)->m_wxwindow ? \
+//	GDK_WINDOW_XWINDOW(((GtkWidget*)piz(wxwin))->window) : \
+//	GDK_WINDOW_XWINDOW((wxwin)->m_widget->window)
 #else
-#define GetXWindow(wxwin) (wxwin)->m_wxwindow ? \
-	GDK_WINDOW_XWINDOW(GTK_PIZZA((wxwin)->m_wxwindow)->bin_window) : \
-	GDK_WINDOW_XWINDOW((wxwin)->m_widget->window)
+//#define GetXWindow(wxwin) (wxwin)->m_wxwindow ? \
+//	GDK_WINDOW_XWINDOW(GTK_PIZZA((wxwin)->m_wxwindow)->bin_window) : \
+//	GDK_WINDOW_XWINDOW((wxwin)->m_widget->window)
 #endif
 #endif
 
@@ -259,11 +272,11 @@ wxVTKRenderWindowInteractor::wxVTKRenderWindowInteractor()
 	, Handle(0)
 	, Created(true)
 	, RenderWhenDisabled(1)
-	, UseCaptureMouse(0)
+	, UseCaptureMouse(1)
 {
 	vtkDebugLeaks::ConstructClass("wxVTKRenderWindowInteractor");
 #if defined(__WXMSW__) || defined(__WXMAC__)
-	this->SetUseCaptureMouse(1);
+	this->SetUseCaptureMouse(0);
 #endif
 #if defined(__WXGTK__) && defined(wxUSE_GLCANVAS) && wxCHECK_VERSION(2, 9, 0)
 	this->GLContext = new wxGLContext (this);
@@ -476,8 +489,8 @@ int wxVTKRenderWindowInteractor::DestroyTimer()
 bool wxVTKRenderWindowInteractor::Reparent( wxWindowBase *newParent )
 {
 	LOG_DEBUG("Core/GL", "Reparenting to " << (void*) newParent << std::endl);
-	return wxWindowBase::Reparent(newParent);
 
+	return wxWindowBase::Reparent(newParent);
 }
 
 //---------------------------------------------------------------------------
@@ -538,7 +551,11 @@ long wxVTKRenderWindowInteractor::GetHandleHack()
 
 	// Find and return the actual X-Window.
 #if defined(__WXGTK__) || defined(__WXX11__)
-	return (long)GetXWindow(this);
+	#if  wxCHECK_VERSION(2, 9, 0)
+		return this->GetXWindow();
+	#else
+		(long)GetXWindow(this);
+	#endif
 #endif
 
 	//#ifdef __WXMOTIF__
@@ -623,25 +640,51 @@ void wxVTKRenderWindowInteractor::OnSize(wxSizeEvent& /*event*/)
 	GetClientSize(&w, &h);
 
 #if defined(__WXGTK__)
-	GdkWindow *window = GTK_PIZZA(m_wxwindow)->bin_window;
-	if (window == NULL) {
-		if (GetHandleHack()) {
-			/*
-			Handle = GetHandleHack();
-			RenderWindow->SetNextWindowId(reinterpret_cast<void *>(Handle));
-			RenderWindow->WindowRemap();
-			*/
-			RenderWindow->SetParentId(reinterpret_cast<void *>(GetXWindow(GetParent())));
-			RenderWindow->SetWindowId(reinterpret_cast<void *>(Handle));
+	#if  wxCHECK_VERSION(2, 9, 0)
+		GtkWidget *widget = GetHandle();
+		if (widget != NULL) {
+			GtkWidget* parent_widget = GetParent()->GetHandle();
+			if (parent_widget != NULL) {
+				gtk_widget_realize(parent_widget);
+   			Window parent_wid = GDK_WINDOW_XWINDOW( parent_widget->window );
+				RenderWindow->SetParentId(reinterpret_cast<void *>(parent_wid));
+			}
+			else {
+				RenderWindow->SetParentId(NULL);
+			}
+         gtk_widget_realize(widget);
+         Window wid = GDK_WINDOW_XWINDOW( widget->window );
+			RenderWindow->SetWindowId(reinterpret_cast<void *>(wid));
+			
+
 			SetCurrent();
 			UpdateSize(w, h);
 			return;
 		}
 		else {
-			SetCurrent();
 			return;
 		}
-	}
+	#else
+		GdkWindow *window = GTK_PIZZA(m_wxwindow)->bin_window;
+		if (window == NULL) {
+			if (GetHandleHack()) {
+				/*
+				Handle = GetHandleHack();
+				RenderWindow->SetNextWindowId(reinterpret_cast<void *>(Handle));
+				RenderWindow->WindowRemap();
+				*/
+				RenderWindow->SetParentId(reinterpret_cast<void *>(GetXWindow(GetParent())));
+				RenderWindow->SetWindowId(reinterpret_cast<void *>(Handle));
+				SetCurrent();
+				UpdateSize(w, h);
+				return;
+			}
+			else {
+				SetCurrent();
+				return;
+			}
+		}
+	#endif
 #endif
 	UpdateSize(w, h);
 
@@ -726,7 +769,6 @@ void wxVTKRenderWindowInteractor::OnLeave(wxMouseEvent &event)
 //---------------------------------------------------------------------------
 void wxVTKRenderWindowInteractor::OnKeyDown(wxKeyEvent &event)
 {
-	bool propagar = false;
 	if (!Enabled)
 	{
 		return;
@@ -755,11 +797,6 @@ void wxVTKRenderWindowInteractor::OnKeyDown(wxKeyEvent &event)
 		keysym = "None";
 	}
 
-	if( keycode==WXK_RIGHT || keycode==WXK_LEFT || keycode==WXK_ESCAPE )
-	{
-		propagar = true;
-	}
-
 	// we don't get a valid mouse position inside the key event on every platform
 	// so we retrieve the mouse position explicitly and pass it along
 	wxPoint mousePos = ScreenToClient(wxGetMousePosition());
@@ -771,7 +808,7 @@ void wxVTKRenderWindowInteractor::OnKeyDown(wxKeyEvent &event)
 		event.GetKeyCode(), 1);
 #endif
 	TransformarEvento(event);
-	if (event.GetSkipped() || propagar) {
+	if (event.GetSkipped()) {
 		event.ResumePropagation(20);
 	}
 }
@@ -818,6 +855,9 @@ void wxVTKRenderWindowInteractor::OnKeyUp(wxKeyEvent &event)
 		event.GetKeyCode(), 1);
 #endif
 	TransformarEvento(event);
+	if (event.GetSkipped()) {
+		event.ResumePropagation(20);
+	}
 	event.Skip();
 
 }
@@ -861,6 +901,9 @@ void wxVTKRenderWindowInteractor::OnChar(wxKeyEvent &event)
 	InvokeEvent(vtkCommand::CharEvent, NULL);
 #endif
 	TransformarEvento(event);
+	if (event.GetSkipped()) {
+		event.ResumePropagation(20);
+	}
 	event.Skip();
 }
 //---------------------------------------------------------------------------
@@ -1038,7 +1081,7 @@ void wxVTKRenderWindowInteractor::OnMouseCaptureLost(wxMouseCaptureLostEvent& /*
 {
 	if (ActiveButton != wxEVT_NULL)
 	{
-		//Maybe also invoke the button release event here
+		//ReleaseMouse();
 	}
 	// Reset ActiveButton so that
 	// 1. we do not process mouse button up events any more,
@@ -1092,9 +1135,31 @@ void wxVTKRenderWindowInteractor::Render()
 
 			Handle = GetHandleHack();
 #if defined(__WXGTK__)
+
+	#if  wxCHECK_VERSION(2, 9, 0)
+			/*
+   	   GtkWidget *widget = GetHandle();
+      	if (widget != NULL) {
+	         GtkWidget* parent_widget = GetParent()->GetHandle();
+   	      if (parent_widget != NULL) {
+         	   gtk_widget_realize(parent_widget);
+	            Window parent_wid = GDK_WINDOW_XWINDOW( parent_widget->window );
+         	   RenderWindow->SetParentId(reinterpret_cast<void *>(parent_wid));
+	   	   }
+   	      else {
+         	   RenderWindow->SetParentId(NULL);
+	         }
+      	   gtk_widget_realize(widget);
+         	Window wid = GDK_WINDOW_XWINDOW( widget->window );
+   	      RenderWindow->SetWindowId(reinterpret_cast<void *>(wid));
+	         SetCurrent();
+      	}
+			*/
+	#else
 			RenderWindow->SetParentId(reinterpret_cast<void *>(GetXWindow(GetParent())));
 			RenderWindow->SetWindowId(reinterpret_cast<void *>(Handle));
 			SetCurrent();
+	#endif
 #elif defined(__WXOSX__)
 			RenderWindow->SetParentId(reinterpret_cast<void *>(this->GetParent()->GetHandle()));
 			RenderWindow->SetWindowId(reinterpret_cast<void *>(Handle));
@@ -1321,7 +1386,7 @@ const char* wx_key_to_key_sym(int i)
 			WXVTK_HANDLE(WXK_WINDOWS_LEFT, "Win_L")
 			WXVTK_HANDLE(WXK_WINDOWS_RIGHT, "Win_R")
 			WXVTK_HANDLE(WXK_WINDOWS_MENU, "Menu")
-			WXVTK_HANDLE(WXK_COMMAND, "Command")
+//NOTHING TO DO..WXK_COMMAND IS "Control_L"			WXVTK_HANDLE(WXK_COMMAND, "Command")
 
 
 	default:
