@@ -265,6 +265,10 @@ public:
 		}
 	}
 
+	const IModeloEstudio* GetStudy() const
+	{
+		return m_pEstudioPadre;
+	}
 protected:
 	std::string m_UID;
 	std::string m_Tipo;
@@ -398,6 +402,11 @@ public:
 		}
 	}
 
+	const IModeloPaciente* GetPatient() const
+	{
+		return m_pPacientePadre;
+	}
+
 protected:
 
 	std::string m_UID;
