@@ -71,6 +71,7 @@
 #endif
 
 #if defined(_WIN32)
+#define _WINSOCKAPI_ 
 #include <windows.h>
 #include <io.h>
 #endif
@@ -117,6 +118,8 @@
 #include <main/controllers/autocleaningcontroller.h>
 #include <main/controllers/modalitysettingscontroller.h>
 #include <main/controllers/anonusagestats.h>
+#include <main/controllers/smartretrievecontroller.h>
+#include <main/controllers/storedqueriescontroller.h>
 
 #include <main/gui/mainwindow/ventanaprincipal.h>
 
@@ -262,10 +265,35 @@ bool Ginkgo::OnInit()
 	RedirectIOToConsole();
 #endif
 
-	wxSocketBase::Initialize();
-
 	wxLog *logger = new wxLogStderr();
 	wxLog::SetActiveTarget(logger);
+
+	{ // TODO Migrate to getopt if params continues growing	
+		for (int i = 1; i < argc; ++i) { // Find the first "not starting with --" argument
+			wxString arg = wxString(argv[i]);
+			if (arg.StartsWith("--config-file")) {
+				wxString::size_type eqPos = arg.find("=");
+				if (eqPos != wxString::npos) {
+					wxString configFilePath = arg.substr(eqPos + 1, std::string::npos);
+				
+					if (!wxFile::Exists(configFilePath)) {
+						LOG_ERROR("INIT", "Specified config file does not exists" << ": " << TOPATH(configFilePath));
+						GNC::GCS::IControladorLog::FreeInstance();
+						GNC::Entorno::FreeInstance();
+						GNC::GCS::ConfigurationController::FreeInstance();
+						return false;
+					}
+					else {
+						GNC::GCS::ConfigurationController::SetPreferredConfigFile(TOPATH(configFilePath));
+					}
+				}
+			}
+		}
+	}
+
+	wxSocketBase::Initialize();
+
+	
 	wxSQLite3Database::InitializeSQLite();
 	//initialize WSA on windows
 #if defined(_WINDOWS)
@@ -319,43 +347,50 @@ bool Ginkgo::OnInit()
 			name, inst_name);
 		if (connection)
 		{
-			
-			if (argc == 2) {
-				wxString str = wxString(argv[1]);
-				if (str.Lower().StartsWith(wxT("ginkgocadx://"))) {
-					LOG_INFO("Core", "The client sends following URL: " << str.ToUTF8());
-					// Ask the other instance to open a file or raise itself
-					connection->Execute(str);
-					connection->Disconnect();
-					delete connection;
+			if (argc > 1) {
+				wxString str;
+				for (int i = 1; i < argc && str.IsEmpty(); ++i) { // Find the first "not starting with --" argument
+					wxString arg = wxString(argv[1]);
+					if (!arg.StartsWith("--")) {
+						str = arg;
+					}
 				}
-				else {
 
-					wxFileName fileName = wxFileName(argv[1]);
-					if (fileName.IsRelative()) {
-						#if defined(__WXGTK__)
-						char* invocation_dir = getenv("INVOCATION_DIR");					
-						if (invocation_dir != NULL) {
-							wxString invocationDir = wxString::FromUTF8(invocation_dir);
-							if (!invocationDir.IsEmpty()) {
-								fileName = invocationDir + wxFileName::GetPathSeparator() + fileName.GetFullPath();
-							}
-						}					
-						#else
-						fileName.MakeAbsolute();
-						#endif
-					}			
-					if (fileName.IsOk() && ((fileName.FileExists() && fileName.IsFileReadable()) || (wxDirExists(fileName.GetFullPath()) && fileName.IsDirReadable()))) {
-						LOG_INFO("Core", "The client sends following file: " << fileName.GetFullPath().ToUTF8());
+				if (!str.IsEmpty()) {				
+					if (str.Lower().StartsWith(wxT("ginkgocadx://"))) {
+						LOG_INFO("Core", "The client sends following URL: " << str.ToUTF8());
 						// Ask the other instance to open a file or raise itself
-						connection->Execute(fileName.GetFullPath());
+						connection->Execute(str);
 						connection->Disconnect();
 						delete connection;
 					}
 					else {
-						wxString err = wxString::Format(wxT("Error: The file %s does not exists or is not readable"), argv[1]);
-						LOG_ERROR("Core", TOPATH(err));
-						wxMessageBox(err, wxT("Ginkgo CADx"), wxICON_INFORMATION|wxOK);
+						wxFileName fileName = wxFileName(argv[1]);
+						if (fileName.IsRelative()) {
+							#if defined(__WXGTK__)
+							char* invocation_dir = getenv("INVOCATION_DIR");					
+							if (invocation_dir != NULL) {
+								wxString invocationDir = wxString::FromUTF8(invocation_dir);
+								if (!invocationDir.IsEmpty()) {
+									fileName = invocationDir + wxFileName::GetPathSeparator() + fileName.GetFullPath();
+								}
+							}					
+							#else
+							fileName.MakeAbsolute();
+							#endif
+						}			
+						if (fileName.IsOk() && ((fileName.FileExists() && fileName.IsFileReadable()) || (wxDirExists(fileName.GetFullPath()) && fileName.IsDirReadable()))) {
+							LOG_INFO("Core", "The client sends following file: " << fileName.GetFullPath().ToUTF8());
+							// Ask the other instance to open a file or raise itself
+							connection->Execute(fileName.GetFullPath());
+							connection->Disconnect();
+							delete connection;
+						}
+						else {
+							wxString err = wxString::Format(wxT("Error: The file %s does not exists or is not readable"), argv[1]);
+							LOG_ERROR("Core", TOPATH(err));
+							wxMessageBox(err, wxT("Ginkgo CADx"), wxICON_INFORMATION|wxOK);
+						}
 					}
 				}
 			} else {
@@ -546,6 +581,12 @@ bool Ginkgo::OnInit()
 	catch(GNC::GCS::IException& ex) {
 		LOG_ERROR("Init", "Error starting PACS Service: " << ex.GetCause());
 	}
+	try {
+		GNC::GCS::SmartRetrieveController::Instance()->resetStatus();
+	}
+	catch(...) {
+		LOG_ERROR("Init", "Error starting smartRetrieve service");
+	}
 
 	DoProgress(wxString(_("Configuring environment ...")));
 
@@ -638,6 +679,8 @@ int Ginkgo::OnExit()
 		LOG_ERROR("Core", _Std("Error unregistering tools: ") << ex.str())
 	}
 
+	GNC::GCS::StoredQueryController::FreeInstance();
+	GNC::GCS::SmartRetrieveController::FreeInstance();
 	GNC::GCS::AutoCleaningController::FreeInstance();
 	GNC::GCS::AnonUsageStats::FreeInstance();
 	GNC::GCS::ThumbnailController::FreeInstance();
