@@ -30,16 +30,16 @@
 GNC::GCS::Nodo GNC::GCS::Nodo::Deserializar(wxXmlNode* nodo)
 {
 	Nodo n;
-	wxString strTmp = nodo->GetPropVal(wxT("x"),wxT("0.0"));
+	wxString strTmp = nodo->GetAttribute(wxT("x"),wxT("0.0"));
 	double doubleTmp;
 	strTmp.ToDouble(&doubleTmp);
 	n.x = (TComp) doubleTmp;
 
-	strTmp = nodo->GetPropVal(wxT("y"),wxT("0.0"));
+	strTmp = nodo->GetAttribute(wxT("y"),wxT("0.0"));
 	strTmp.ToDouble(&doubleTmp);
 	n.y = (TComp) doubleTmp;
 
-	strTmp = nodo->GetPropVal(wxT("size"),wxT("10.0"));
+	strTmp = nodo->GetAttribute(wxT("size"),wxT("10.0"));
 	strTmp.ToDouble(&doubleTmp);
 	n.m_Size = (float) doubleTmp;
 
@@ -51,9 +51,9 @@ GNC::GCS::Nodo GNC::GCS::Nodo::Deserializar(wxXmlNode* nodo)
 wxXmlNode* GNC::GCS::Nodo::Serializar()
 {
 	wxXmlNode* resultado = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("node"));
-	resultado->AddProperty(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),x)));
-	resultado->AddProperty(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),y)));
-	resultado->AddProperty(new wxXmlProperty(wxT("size"),wxString::Format(wxT("%f"),m_Size)));
+	resultado->AddAttribute(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),x)));
+	resultado->AddAttribute(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),y)));
+	resultado->AddAttribute(new wxXmlProperty(wxT("size"),wxString::Format(wxT("%f"),m_Size)));
 	return resultado;
 }
 
