@@ -23,7 +23,7 @@ class wxXmlNode;
 class wxWindow;
 class wxEvtHandler;
 class wxMenu;
-class wxAuiToolBar;
+class wxGinkgoToolBar;
 
 namespace GNC {
 	namespace GCS {
@@ -50,12 +50,15 @@ namespace GNC {
 			virtual void ReconnectToolController() = 0;
 			virtual void FinalizeToolController() = 0;
 
+			//register tool key events to parent window
+			virtual void ConnectKeyEvents(wxWindow* pParent) = 0;
+
 			virtual wxWindow* CreateNewToolBar(wxWindow* pParent, bool alignLeft = true) = 0;
 			virtual wxWindow* CreateNewToolBar(wxWindow* pParent, GNC::GCS::ITool::TToolFamily family, bool alignLeft = true) = 0;
 			virtual wxWindow* CreateNewToolBar(wxWindow* pParent, const TIdList& toolsToInclude, bool alignLeft = true) = 0;
 			virtual void AppendsToolInMenu(wxEvtHandler* pParent, wxMenu* pMenu, GNC::GCS::ITool::TToolFamily family) = 0;
-			virtual void AppendsToolsInToolBar(wxAuiToolBar* pToolBar, GNC::GCS::ITool::TToolFamily family) = 0;
-			virtual void AppendsToolsInToolBar(wxAuiToolBar* pToolBar, const GNC::GCS::IToolController::TIdList& toolsToInclude) = 0;
+			virtual void AppendsToolsInToolBar(wxGinkgoToolBar* pToolBar, GNC::GCS::ITool::TToolFamily family) = 0;
+			virtual void AppendsToolsInToolBar(wxGinkgoToolBar* pToolBar, const GNC::GCS::IToolController::TIdList& toolsToInclude) = 0;
 
 			virtual void OnKeyAccelerator(GNC::GCS::Events::EventoTeclado& evento, wxWindow* pWindow) = 0;
 
