@@ -34,7 +34,7 @@ namespace GNC {
 			virtual void Connect() = 0;
 			virtual void Disconnect() = 0;
 
-			virtual void AppendToolIn(wxAuiToolBar* pParent);
+			virtual void AppendToolIn(wxGinkgoToolBar* pParent);
 
 			TriggerButton& GetTriggerButton() {
 				return m_TriggerButtonMask;
