@@ -82,10 +82,7 @@ void GADAPI::AutoCleaningCommand::Execute()
 			if (!NotificarProgreso((double)progress/studyList.size(),tarea)) {
 				return;
 			}
-			//skip studies with pending tasks
-			if ((*it).pending_tasks == 0) {
-				GNC::GCS::HistoryController::Instance()->GetSeriesFromStudy((*it).pk, m_pAutoCleaningParameters->seriesToDelete);
-			}
+			GNC::GCS::HistoryController::Instance()->GetSeriesFromStudy((*it).pk, m_pAutoCleaningParameters->seriesToDelete);
 		}
 	}
 
@@ -149,23 +146,20 @@ void GADAPI::AutoCleaningCommand::Execute()
 			if (!NotificarProgreso((double)progress/studyList.size(),tarea)) {
 				return;
 			}
-			//skip studies with pending tasks
-			if ((*itStudy).pending_tasks == 0) {
-				//calculate study size to delete it...
-				GNC::GCS::HistoryController::SeriesModelList series;
-				GNC::GCS::HistoryController::Instance()->GetSeriesFromStudy((*itStudy).pk, series);
-				for (GNC::GCS::HistoryController::SeriesModelList::iterator itSeries = series.begin(); itSeries != series.end(); ++itSeries) {
-					GNC::GCS::HistoryController::LightFileModelList files;
-					GNC::GCS::HistoryController::Instance()->GetSeriesSortedFileModels((*itSeries).pk, files);
-					for (GNC::GCS::HistoryController::LightFileModelList::iterator itFiles = files.begin(); itFiles != files.end(); ++itFiles) {
-						if ((*itFiles).location == GNC::GCS::HistoryController::TL_LocalDatabase) {
-							wxFileName fn(FROMPATH((*itFiles).real_path));
-							spaceToFree -= fn.GetSize().GetValue();
-						}
+			//calculate study size to delete it...
+			GNC::GCS::HistoryController::SeriesModelList series;
+			GNC::GCS::HistoryController::Instance()->GetSeriesFromStudy((*itStudy).pk, series);
+			for (GNC::GCS::HistoryController::SeriesModelList::iterator itSeries = series.begin(); itSeries != series.end(); ++itSeries) {
+				GNC::GCS::HistoryController::LightFileModelList files;
+				GNC::GCS::HistoryController::Instance()->GetSeriesSortedFileModels((*itSeries).pk, files);
+				for (GNC::GCS::HistoryController::LightFileModelList::iterator itFiles = files.begin(); itFiles != files.end(); ++itFiles) {
+					if ((*itFiles).location == GNC::GCS::HistoryController::TL_LocalDatabase) {
+						wxFileName fn(FROMPATH((*itFiles).real_path));
+						spaceToFree -= fn.GetSize().GetValue();
 					}
-					m_pAutoCleaningParameters->seriesToDelete.push_back((*itSeries));
 				}
-			}
+				m_pAutoCleaningParameters->seriesToDelete.push_back((*itSeries));
+			}			
 		}
 	}
 }
