@@ -11,7 +11,6 @@
 *
 */
 
-//#define _GINKGO_TRACE
 #include <sstream>
 #include <api/internationalization/internationalization.h>
 
@@ -19,8 +18,8 @@
 #include <wx/msgdlg.h>
 #include <wx/sstream.h>
 #include <wx/url.h>
-#include <wx/wxhttpengine/httpbuilder.h>
 #include <main/controllers/configurationcontroller.h>
+#include <main/controllers/pacscontroller.h>
 
 #include <api/globals.h>
 
@@ -37,12 +36,10 @@ GNC::ComandoComprobarActualizacionesParams::ComandoComprobarActualizacionesParam
 		m_URL(url),
 		m_Informar(informar) 
 {
-	m_pBuilder = new wxHTTPBuilder();
 }
 
 GNC::ComandoComprobarActualizacionesParams::~ComandoComprobarActualizacionesParams()
 {
-	delete m_pBuilder;
 }
 
 GNC::ComandoComprobarActualizaciones::ComandoComprobarActualizaciones(ComandoComprobarActualizacionesParams* pParams) :
@@ -80,32 +77,31 @@ int GNC::ComandoComprobarActualizaciones::GetRevision() const
 
 void GNC::ComandoComprobarActualizaciones::Execute()
 {
-	std::string tarea(_Std("Checking program updates..."));
-	NotificarProgreso(0.0, tarea);
+//	NotificarProgreso(0.0, tarea);
 
 	if (EstaAbortado()) {
 		return;
 	}
 
+	std::string tmpFile = GNC::Entorno::Instance()->CreateGinkgoTempFile();
 	try {
-		wxHTTPBuilder& builder = *m_pComprobarActualizacionesParams->m_pBuilder;
-		wxProxySettings settings;
-		settings.ProxySettingsLoadGeneral();
-		builder.SetProxySettings(settings);
-		builder.InitContentTypes();
-
-		wxInputStream* inputStream = builder.GetInputStream2(wxString::FromUTF8(m_pComprobarActualizacionesParams->m_URL.c_str()));
-
-		if (builder.GetError() != wxPROTO_NOERR) {
-			std::ostringstream os;
-			os << builder.GetLastError().ToUTF8();
-			os << ". URL = " << m_pComprobarActualizacionesParams->m_URL;
-			m_Error  = os.str();
+		if (!GIL::DICOM::PACSController::Instance()->DownloadFileFromURL(m_pComprobarActualizacionesParams->m_URL, tmpFile, this)) {
+			std::ostringstream ostr;
+			ostr << "Error downloading update file: " << m_pComprobarActualizacionesParams->m_URL << " check http proxy settings";
+			m_Error = ostr.str();
 			return;
 		}
+	} catch (GIL::DICOM::PACSException& ex) {
+		std::ostringstream ostr;
+		ostr << "Error downloading update file: " << m_pComprobarActualizacionesParams->m_URL << " check http proxy settings";
+		m_Error = ostr.str();
+		return;
+	}
 
+
+	try {
 		wxXmlDocument xml;
-		xml.Load(*inputStream, wxT("UTF-8"));
+		xml.Load(FROMPATH(tmpFile));
 		wxXmlNode* raiz = xml.GetRoot();
 		if (raiz == NULL) {
 			m_Error = "XML invalid";
@@ -135,7 +131,6 @@ void GNC::ComandoComprobarActualizaciones::Execute()
 				}
 			}
 		}
-		delete inputStream;
 
 		if (m_URL.empty()) {
 			m_Error = _Std("Not enough parameters found on XML");
@@ -150,7 +145,6 @@ void GNC::ComandoComprobarActualizaciones::Execute()
 		m_Error = _Std("XML parsing internal error");
 		Abort();
 	}
-	GTRACE("Saliendo comando ComprobarActualizaciones ");
 }
 
 void GNC::ComandoComprobarActualizaciones::Update()
@@ -178,9 +172,4 @@ void GNC::ComandoComprobarActualizaciones::Update()
 
 }
 
-void GNC::ComandoComprobarActualizaciones::OnAbort()
-{
-	m_pComprobarActualizacionesParams->m_pBuilder->Stop();
-	m_pComprobarActualizacionesParams->m_pBuilder->Abort();
-}
 
