@@ -15,6 +15,16 @@
 #pragma once
 #include "dicomassociation.h"
 #include <api/dicom/imodelodicom.h>
+#include <list>
+#include <api/autoptr.h>
+
+class DicomServer;
+namespace GIL {
+	namespace DICOM
+	{
+		class DicomDataset;
+	}
+}
 
 class FindAssociation : public Association {
 public:
@@ -42,7 +52,7 @@ public:
 	{
 		switch (frqi) {
 			case FRQRIM_Patient:
-				Association::m_abstractSyntax = (char *) UID_FINDPatientRootQueryRetrieveInformationModel;
+				Association::m_abstractSyntax = (char *) UID_FINDStudyRootQueryRetrieveInformationModel;
 				break;
 			case FRQRIM_Study:
 				Association::m_abstractSyntax = (char *) UID_FINDStudyRootQueryRetrieveInformationModel;
@@ -91,6 +101,11 @@ public:
 	 Set the maximum number of results
 	 */
 	void SetMaxResults(int max);
+
+	/**
+	Set results wrapper to do incremental finds
+	*/
+	void SetCallbackInfo(std::list< GNC::GCS::Ptr<GIL::DICOM::DicomDataset> >* pRwrapper, const GNC::GCS::Ptr<DicomServer>& dicomServer);
 	
 	/**
 	 Get the maximum number of results
@@ -128,6 +143,8 @@ private:
 	 */
 	static void findCallback(void*, T_DIMSE_C_FindRQ*, int responseCount, T_DIMSE_C_FindRSP*, DcmDataset *responseIdentifiers);
 	int maxResults;
+	std::list< GNC::GCS::Ptr<GIL::DICOM::DicomDataset> >* pResultsWrapper;
+	GNC::GCS::Ptr<DicomServer> pDicomServer;
 	
 	virtual void OnAddPresentationContext(T_ASC_Parameters* params);
 	
