@@ -428,10 +428,15 @@ OFCondition Document2Dcm::incrementInstanceNumber(DcmDataset *targetDset)
 			std::ostringstream os;
 			os << OFstatic_cast(long, instanceNumber);
 			OFCondition cond = targetDset->putAndInsertOFStringArray(DCM_InstanceNumber, os.str().c_str());
-			if (cond.bad())
+			if (cond.bad()) {
 				return makeOFCondition(OFM_dcmdata, 18, OF_error, "Unable write Instance Number to dataset");
-		} else
-			return makeOFCondition(OFM_dcmdata, 18, OF_error, "Unable to read Instance Number from dataset");
+			}
+		} else {
+			OFCondition cond = targetDset->putAndInsertOFStringArray(DCM_InstanceNumber, "1");
+			if (cond.bad()) {
+				return makeOFCondition(OFM_dcmdata, 18, OF_error, "Unable write Instance Number to dataset");
+			}			
+		}
 	}
 	return EC_Normal;
 }
