@@ -137,10 +137,11 @@ inline std::string GetDateTimeFromWx(const wxString& dateStr) {
 		if (time.IsValid()) {
 			size_t posPoint = dateStr.Find('.', true);
 			if (posPoint != wxString::npos) {
-				long milli;
-				wxString tmp = dateStr.substr(posPoint);
-				tmp.ToLong(&milli);
-				time.SetMillisecond(milli);
+				long milli=0;
+				wxString tmp = dateStr.substr(posPoint+1);
+				if (tmp.ToLong(&milli)) {
+					time.SetMillisecond(milli);
+				}
 			}
 			date.Set(date.GetDay(), date.GetMonth(), date.GetYear(), time.GetHour(), time.GetMinute(), time.GetSecond(), time.GetMillisecond());
 		}
@@ -205,13 +206,13 @@ std::string GNC::GCS::History::AcquisitionDateFilter::GetSQLFilter()
 	if (from.IsValid() && to.IsValid()) {
 		std::string tmpFrom(from.Format(wxT("%Y-%m-%d %H:%M:%S")).ToUTF8());
 		std::string tmpTo(to.Format(wxT("%Y-%m-%dT%H:%M:%S")).ToUTF8());
-		ostr << bufSQL.Format(" Study.created_time BETWEEN '%q' AND '%q'", tmpFrom.c_str(), tmpTo.c_str());
+		ostr << bufSQL.Format(" Study.study_datetime BETWEEN '%q' AND '%q'", tmpFrom.c_str(), tmpTo.c_str());
 	} else if (from.IsValid()) {
 		std::string tmpStr(from.Format(wxT("%Y-%m-%d %H:%M:%S")).ToUTF8());
-		ostr << bufSQL.Format(" Study.created_time >= '%q'",  tmpStr.c_str());
+		ostr << bufSQL.Format(" Study.study_datetime >= '%q'",  tmpStr.c_str());
 	} else	if (to.IsValid()) {
 		std::string tmpStr(to.Format(wxT("%Y-%m-%d %H:%M:%S")).ToUTF8());
-		ostr << bufSQL.Format(" Study.created_time <= '%q'", tmpStr.c_str());
+		ostr << bufSQL.Format(" Study.study_datetime <= '%q'", tmpStr.c_str());
 	}
 	return ostr.str();
 }
@@ -596,9 +597,9 @@ bool GNC::GCS::HistoryController::AddFiles(const StringList& listaPaths, TAddErr
 
 							if(wxCopyFile(FROMPATH((*it)),pathDicom)) {
 								#ifdef _WIN32
-								_chmod(TOPATH(pathDicom), _S_IWRITE);
+								_chmod(TOPATH(pathDicom).c_str(), _S_IWRITE);
 								#else 
-								chmod(TOPATH(pathDicom), 0644);
+								chmod(TOPATH(pathDicom).c_str(), 0644);
 								#endif
 								if(action == TAA_MOVE) {
 									wxRemoveFile(FROMPATH((*it)));
@@ -1032,7 +1033,7 @@ std::string GNC::GCS::HistoryController::GetPathOfFile(GNC::GCS::IHistoryControl
 				wxFileName::Mkdir(rootDir, 0700);
 			}
 			pathDicom += wxFileName::GetPathSeparator();
-			pathDicom += wxString::Format(wxT("%d"), pk);
+			pathDicom += wxString::Format(wxT("%d"), (int) pk);
 			return std::string(TOPATH(pathDicom));
 		}
 		break;
@@ -1055,7 +1056,7 @@ std::string GNC::GCS::HistoryController::GetPathOfFile(long file_pk)
 		wxFileName::Mkdir(rootDir, 0700);
 	}
 	pathDicom += wxFileName::GetPathSeparator();
-	pathDicom += wxString::Format(wxT("%d"), file_pk);
+	pathDicom += wxString::Format(wxT("%d"), (int) file_pk);
 	return std::string(TOPATH(pathDicom));
 }
 
@@ -1181,10 +1182,6 @@ inline void FillInSeriesModel(wxSQLite3ResultSet& resultados, GNC::GCS::HistoryC
 		seriesModel.updated_time = GetDateTimeFromWx(resultados.GetAsString(wxT("updated_time")));
 		seriesModel.location = GNC::GCS::IHistoryController::CharToLocation(*resultados.GetString(wxT("location")).ToUTF8());
 	}
-	const long task_pk = resultados.GetInt64(wxT("task_pk")).GetValue();
-	if (task_pk > 0) {
-		seriesModel.pendingTasks.push_back(task_pk);
-	}
 }
 
 GNC::GCS::HistoryController::SeriesModel GNC::GCS::HistoryController::GetSeriesModel(long series_pk)
@@ -1195,14 +1192,9 @@ GNC::GCS::HistoryController::SeriesModel GNC::GCS::HistoryController::GetSeriesM
 		bufSQL.Format("SELECT Series.pk, Series.study_fk, Series.series_iuid, Series.series_datetime, Series.series_no,Series.modality,"
 			"Series.uid_importer, Series.body_part, Series.laterality, Series.series_desc,"
 			"Series.institution,Series.station_name,Series.department,Series.perf_physician,"
-			"Series.num_instances, Series.frame_of_reference_uid, Series.tuids_in_series, Series.created_time, Series.updated_time, Series.location, "
-			"task_pk "
+			"Series.num_instances, Series.frame_of_reference_uid, Series.tuids_in_series, Series.created_time, Series.updated_time, Series.location "
 			"FROM Series "
-			"LEFT OUTER JOIN ("
-				"select distinct TasksSeries.task_fk as task_pk, series_fk from TasksSeries, Tasks "
-				"where series_fk = '%ld' AND TasksSeries.task_fk = Tasks.pk AND Tasks.status IN('%d','%d') "
-				") on series_fk=pk "
-			"WHERE pk = '%ld'", series_pk,GNC::GCS::IPersistentCommand::Pending,GNC::GCS::IPersistentCommand::Error, series_pk);
+			"WHERE pk = '%ld'", series_pk);
 		wxSQLite3ResultSet resultados = m_pConexion->ExecuteQuery(bufSQL);
 		while (resultados.NextRow()) {
 			FillInSeriesModel(resultados, seriesModel);
@@ -1244,14 +1236,9 @@ void GNC::GCS::HistoryController::GetSeriesModelFromUIDs(const GNC::GCS::History
 		ostr << bufSQL.Format("SELECT Series.pk, Series.study_fk, Series.series_iuid, Series.series_datetime, Series.series_no,Series.modality,"
 			"Series.uid_importer, Series.body_part, Series.laterality, Series.series_desc,"
 			"Series.institution,Series.station_name,Series.department,Series.perf_physician,"
-			"Series.num_instances, Series.frame_of_reference_uid, Series.tuids_in_series, Series.location, Series.created_time, Series.updated_time, "
-			"task_pk "
+			"Series.num_instances, Series.frame_of_reference_uid, Series.tuids_in_series, Series.location, Series.created_time, Series.updated_time "
 			"FROM Series "
-			"LEFT OUTER JOIN ("
-				"select distinct TasksSeries.task_fk as task_pk, series_fk from TasksSeries, Tasks "
-				"where TasksSeries.task_fk = Tasks.pk AND Tasks.status IN('%d','%d') "
-				") on series_fk=pk "
-			"WHERE series_iuid IN (",GNC::GCS::IPersistentCommand::Pending,GNC::GCS::IPersistentCommand::Error);
+			"WHERE series_iuid IN (");
 		for (GNC::GCS::HistoryController::StringList::const_iterator itUid = uids.begin(); itUid != uids.end(); ++itUid) {
 			if (itUid != uids.begin()) {
 				ostr << ",";
@@ -1288,14 +1275,9 @@ void GNC::GCS::HistoryController::GetSeriesFromStudy(long study_pk, GNC::GCS::Hi
 		bufSQL.Format("SELECT Series.pk, Series.study_fk, Series.series_iuid, Series.series_datetime, Series.series_no,Series.modality,"
 			"Series.uid_importer, Series.body_part, Series.laterality, Series.series_desc,"
 			"Series.institution,Series.station_name,Series.department,Series.perf_physician,"
-			"Series.num_instances, Series.frame_of_reference_uid, Series.location, Series.tuids_in_series, Series.created_time, Series.updated_time, "
-			"task_pk "
+			"Series.num_instances, Series.frame_of_reference_uid, Series.location, Series.tuids_in_series, Series.created_time, Series.updated_time "
 			"FROM Series "
-			"LEFT OUTER JOIN ("
-				"select distinct TasksSeries.task_fk as task_pk, series_fk from TasksSeries, Tasks "
-				"where TasksSeries.task_fk = Tasks.pk AND Tasks.status IN('%d','%d') "
-				") on series_fk=pk "
-			"WHERE study_fk = '%d'",GNC::GCS::IPersistentCommand::Pending,GNC::GCS::IPersistentCommand::Error, study_pk);
+			"WHERE study_fk = '%d'",study_pk);
 		wxSQLite3ResultSet resultados = m_pConexion->ExecuteQuery(bufSQL);
 		std::map<long, SeriesModel> mapOfSeries;
 		while (resultados.NextRow()) {
@@ -1331,7 +1313,6 @@ inline void FillInStudyModel(wxSQLite3ResultSet& resultados, GNC::GCS::HistoryCo
 	studyModel.num_instances = resultados.GetInt64(wxT("num_instances")).GetValue();
 	studyModel.created_time = GetDateTimeFromWx(resultados.GetAsString(wxT("created_time")));
 	studyModel.updated_time = GetDateTimeFromWx(resultados.GetAsString(wxT("updated_time")));
-	studyModel.pending_tasks = resultados.GetInt(wxT("pending_tasks"));
 	studyModel.location = GNC::GCS::IHistoryController::CharToLocation(*resultados.GetString(wxT("location")).ToUTF8());
 }
 
@@ -1343,15 +1324,9 @@ GNC::GCS::HistoryController::StudyModel GNC::GCS::HistoryController::GetStudyMod
 		bufSQL.Format("SELECT Study.pk, Study.pat_id, Study.pat_id_issuer, Study.pat_name, Study.pat_birthdate,Study.pat_sex,"
 			"Study.study_iuid, Study.study_id, Study.study_datetime, Study.accession_no,"
 			"Study.ref_physician,Study.study_desc,Study.mods_in_study,Study.cuids_in_study,"
-			"Study.num_series, Study.num_instances, Study.location, Study.created_time, Study.updated_time, "
-			"pending_tasks "
+			"Study.num_series, Study.num_instances, Study.location, Study.created_time, Study.updated_time "
 			"FROM Study "
-			"LEFT OUTER JOIN ("
-				"select count(distinct TasksSeries.task_fk) as pending_tasks, study_fk from TasksSeries, Tasks, Series "
-				"where Series.pk = TasksSeries.series_fk AND TasksSeries.task_fk = Tasks.pk AND Tasks.status IN('%d','%d') "
-				"GROUP by study_fk "
-				") on study_fk=pk "
-			"WHERE pk = '%ld'", GNC::GCS::IPersistentCommand::Pending,GNC::GCS::IPersistentCommand::Error,study_pk);
+			"WHERE pk = '%ld'",study_pk);
 		wxSQLite3ResultSet resultados = m_pConexion->ExecuteQuery(bufSQL);
 		if (resultados.NextRow()) {
 			FillInStudyModel(resultados, studyModel);
@@ -1371,15 +1346,9 @@ void GNC::GCS::HistoryController::GetStudyModelFromUID(const std::string& uid, G
 		bufSQL.Format("SELECT Study.pk, Study.pat_id, Study.pat_id_issuer, Study.pat_name, Study.pat_birthdate,Study.pat_sex,"
 			"Study.study_iuid, Study.study_id, Study.study_datetime, Study.accession_no,"
 			"Study.ref_physician,Study.study_desc,Study.mods_in_study,Study.cuids_in_study,"
-			"Study.num_series, Study.num_instances, Study.location, Study.created_time, Study.updated_time, "
-			"pending_tasks "
+			"Study.num_series, Study.num_instances, Study.location, Study.created_time, Study.updated_time "
 			"FROM Study "
-			"LEFT OUTER JOIN ("
-				"select count(distinct TasksSeries.task_fk) as pending_tasks, study_fk from TasksSeries, Tasks, Series "
-				"where Series.pk = TasksSeries.series_fk AND TasksSeries.task_fk = Tasks.pk AND Tasks.status IN('%d','%d') "
-				"GROUP by study_fk "
-				") on study_fk=pk "
-				"WHERE study_iuid = '%q'", GNC::GCS::IPersistentCommand::Pending,GNC::GCS::IPersistentCommand::Error,uid.c_str());
+			"WHERE study_iuid = '%q'", uid.c_str());
 		wxSQLite3ResultSet resultados = m_pConexion->ExecuteQuery(bufSQL);
 		std::map<long, StudyModel> mapOfStudies;
 		while (resultados.NextRow()) {
@@ -1435,14 +1404,8 @@ void GNC::GCS::HistoryController::GetStudies(std::list<GNC::GCS::History::IHisto
 		ostr << bufSQL.Format("SELECT Study.pk, Study.pat_id, Study.pat_id_issuer, Study.pat_name, Study.pat_birthdate,Study.pat_sex,"
 				"Study.study_iuid, Study.study_id, Study.study_datetime, Study.accession_no,"
 				"Study.ref_physician,Study.study_desc,Study.mods_in_study,Study.cuids_in_study,"
-				"Study.num_series, Study.num_instances, Study.location, Study.created_time, Study.updated_time, "
-				"pending_tasks "
-				"FROM Study "
-				"LEFT OUTER JOIN ("
-					"select count(distinct TasksSeries.task_fk) as pending_tasks, study_fk from TasksSeries, Tasks, Series "
-					"where Series.pk = TasksSeries.series_fk AND TasksSeries.task_fk = Tasks.pk AND Tasks.status IN('%d','%d') "
-					"GROUP by study_fk "
-				") on study_fk=pk ", GNC::GCS::IPersistentCommand::Pending,GNC::GCS::IPersistentCommand::Error);
+				"Study.num_series, Study.num_instances, Study.location, Study.created_time, Study.updated_time "
+				"FROM Study ");
 		bool first = true;
 		for (std::list<GNC::GCS::History::IHistoryFilter*>::iterator it = historyFilter.begin(); it != historyFilter.end(); ++it) {
 			if ((*it)->IsEnabled()) {
