@@ -29,6 +29,8 @@
 #include "guiappender.h"
 #include <api/internationalization/internationalization.h>
 
+#define MAX_LOG_BUFFER_SIZE 30
+
 using namespace log4cplus::helpers;
 
 gnkLog4cplus::GUIAppender* gnkLog4cplus::GUIAppender::m_pInstancia = NULL;
@@ -138,6 +140,10 @@ void gnkLog4cplus::GUIAppender::append(const log4cplus::spi::InternalLoggingEven
 	if (m_pLogger != NULL) {
 		m_pLogger->Append(m_Logs.back());
 	}
+
+	if (m_Logs.size() > MAX_LOG_BUFFER_SIZE) {
+		m_Logs.pop_front();
+	}
 	
     LOG4CPLUS_END_SYNCHRONIZE_ON_MUTEX;
 }
