@@ -147,7 +147,7 @@ wxXmlNode* GNC::GCS::AnnotationSettings::serialize()
 	wxXmlNode* wlNode = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, AS_ROOT);
 	for (int i = 0; i < TP_NumPos; ++i) {
 		wxXmlNode* annotationNode = new wxXmlNode(wlNode, wxXML_ELEMENT_NODE, AN_NODE);
-		annotationNode->AddAttribute(AN_ATT_POS, wxString::Format(wxT("%d"), i));
+		annotationNode->AddAttribute(AN_ATT_POS, wxString::Format(wxT("%d"), (int) i));
 		annotationNode->AddAttribute(AN_ATT_VALUE, wxString::FromUTF8(annotation[i].c_str()));
 	}
 
@@ -196,8 +196,8 @@ GNC::GCS::WindowLevelSetting::~WindowLevelSetting()
 wxXmlNode* GNC::GCS::WindowLevelSetting::serialize()
 {
 	wxXmlNode* wlNode = new wxXmlNode(NULL, wxXML_ELEMENT_NODE, WL_ROOT);
-	wlNode->AddAttribute(WL_ATT_WINDOW, wxString::Format(wxT("%lf"),this->window));
-	wlNode->AddAttribute(WL_ATT_LEVEL, wxString::Format(wxT("%lf"),this->level));
+	wlNode->AddAttribute(WL_ATT_WINDOW, wxString::Format(wxT("%lf"), this->window));
+	wlNode->AddAttribute(WL_ATT_LEVEL, wxString::Format(wxT("%lf"), this->level));
 	wlNode->AddAttribute(WL_ATT_LABEL, wxString::FromUTF8(this->label.c_str()));	
 
 	return wlNode;
