@@ -37,7 +37,6 @@
 #include <wx/dir.h>
 #include <wx/file.h>
 #include <wx/tokenzr.h>
-#include <wx/wxhttpengine/httpbuilder.h>
 #include <main/controllers/configurationcontroller.h>
 #include <main/controllers/historycontroller.h>
 #include <main/controllers/dicommanager.h>
@@ -142,395 +141,6 @@ namespace GIL {
 
 		}
 
-		IModeloDicom* PACSController::BuscarPaciente(
-			void* connectionKey,
-			const std::string& serverId,
-			const std::string& idPaciente,
-			const std::string& nombrePaciente,
-			const std::string& /*fechaNacimiento*/,
-			IModeloDicom* pModelo,
-			GNC::IProxyNotificadorProgreso* pNotificador
-			)
-		{
-			DicomServerList* listaServidores = DicomServerList::Instance();
-			GNC::GCS::Ptr<DicomServer> server = listaServidores->GetServer(serverId);
-
-			wxCSConv conv = GetConv(server->GetDefaultCharset());
-
-			DcmDataset query;
-			DcmElement* e = NULL;
-
-			e = newDicomElement(DCM_SpecificCharacterSet);
-			e->putString(server->GetDefaultCharset().c_str());
-			query.insert(e);
-
-			e = newDicomElement(DCM_QueryRetrieveLevel);
-			e->putString(wxString( "PATIENT", wxConvUTF8).mb_str(conv));
-			query.insert(e);
-
-			e = newDicomElement(DCM_PatientID);
-			e->putString(wxString( idPaciente.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_PatientName);
-			e->putString(wxString( nombrePaciente.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_PatientBirthDate);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_PatientSex);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_ReferringPhysicianName);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			NetClient<FindAssociation> a(GIL::DICOM::DCMTK::Network::Instance(connectionKey), "C-FIND", pNotificador);
-
-			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
-
-			if (server->useTLS) {
-				a.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
-			}
-			if (server->GetPACSUser() != "") {
-				a.SetUserPass(server->GetPACSUser(), server->GetPACSPass());
-			}
-
-			a.QueryServer(&query, server, pModelo, localAET, CT_FindPacientes);
-
-			return pModelo;
-		}
-
-		IModeloDicom* PACSController::BuscarEstudio(
-			void* connectionKey,
-			const std::string& serverId,
-			const std::string& idPaciente,
-			const std::string& nombrePaciente,
-			const std::string& idEstudio,
-			const std::string& AccNumber,
-			const std::string& modality,
-			const std::string& fechaDesde,
-			const std::string& fechaHasta,
-			const std::string& timeFrom,
-			const std::string& timeTo,
-			const std::string& descripcionEstudio,
-			const std::string& WXUNUSED(nombreEstacion),
-			IModeloDicom* pModelo,
-			GNC::IProxyNotificadorProgreso* pNotificador
-			)
-		{
-			DicomServerList* listaServidores = DicomServerList::Instance();
-			GNC::GCS::Ptr<DicomServer> server = listaServidores->GetServer(serverId);
-
-			wxCSConv conv = GetConv(server->GetDefaultCharset());
-
-			std::string description;
-			if (!descripcionEstudio.empty()) {
-				description = descripcionEstudio;
-			}
-
-			// create date querystring
-			std::string date;
-			if (fechaDesde.empty() && fechaHasta.empty()) {
-				date = "";
-			} else {
-				date = fechaDesde + "-" + fechaHasta;
-			}
-
-			if (fechaDesde == fechaHasta) {
-				date = fechaDesde;
-			}
-
-			std::string time;
-			if (timeFrom.empty() && timeTo.empty()) {
-				time = "";
-			} else {
-				time = timeFrom + "-" + timeTo;
-			}
-
-			if (timeFrom == timeTo) {
-				time = timeFrom;
-			}
-
-			std::string station;
-			DcmDataset query;
-			DcmElement* e = NULL;
-
-			e = newDicomElement(DCM_SpecificCharacterSet);
-			e->putString(server->GetDefaultCharset().c_str());
-			query.insert(e);
-
-			e = newDicomElement(DCM_QueryRetrieveLevel);
-			e->putString(wxString( "STUDY", wxConvUTF8).mb_str(conv));
-			query.insert(e);
-
-			e = newDicomElement(DCM_PatientName);
-			e->putString(wxString( nombrePaciente.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_PatientID);
-			e->putString(wxString( idPaciente.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_ModalitiesInStudy);
-			if (modality != "*" && modality != "") {
-				e->putString(wxString( modality.c_str(), wxConvUTF8).mb_str(conv));
-			}
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_PatientBirthDate);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_PatientSex);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_StudyDate);
-			e->putString(wxString( date.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_StudyTime);
-			e->putString(time.c_str());
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_StudyID);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_StudyInstanceUID);
-			e->putString(wxString( idEstudio.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_StudyDescription);
-			e->putString(wxString( description.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_AccessionNumber);
-			e->putString(wxString( AccNumber.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_StationName);
-			e->putString(wxString( station.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_ReferringPhysicianName);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			NetClient<FindAssociation> a(connectionKey, "C-FIND", pNotificador);
-
-			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
-
-
-			if (server->useTLS) {
-				a.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
-			}
-			if (server->GetPACSUser() != "") {
-				a.SetUserPass(server->GetPACSUser(), server->GetPACSPass());
-			}
-			a.QueryServer(&query, server, pModelo, localAET, CT_FindEstudios);
-
-			return pModelo;
-		}
-
-		IModeloDicom* PACSController::BuscarSeries(
-			void* connectionKey,
-			const std::string& serverId,
-			const std::string& idEstudio,
-			const std::string& idSerie,
-			IModeloDicom* pModelo,
-			GNC::IProxyNotificadorProgreso* pNotificador
-			)
-		{
-			DicomServerList* listaServidores = DicomServerList::Instance();
-			GNC::GCS::Ptr<DicomServer> server = listaServidores->GetServer(serverId);
-
-			wxCSConv conv = GetConv(server->GetDefaultCharset());
-
-			std::string estudioId;
-			std::string serieId;
-
-			if (!idEstudio.empty()) {
-				estudioId.assign(idEstudio.c_str());
-			}
-
-			if (!idSerie.empty()) {
-				serieId.assign(idSerie.c_str());
-			}
-
-			DcmDataset query;
-			DcmElement* e = NULL;
-
-			e = newDicomElement(DCM_SpecificCharacterSet);
-			e->putString(server->GetDefaultCharset().c_str());
-			query.insert(e);
-
-			e = newDicomElement(DCM_QueryRetrieveLevel);
-			e->putString(wxString( "SERIES", wxConvUTF8).mb_str(conv));
-			query.insert(e);
-
-			e = newDicomElement(DCM_StudyInstanceUID);
-			e->putString(wxString( estudioId.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_SeriesInstanceUID);
-			e->putString(wxString( serieId.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_Modality);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_SeriesDescription);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_SeriesDate);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_SeriesTime);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_NumberOfSeriesRelatedInstances);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_ReferringPhysicianName);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			NetClient<FindAssociation> a(connectionKey, "C-FIND", pNotificador);
-
-			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
-
-			if (server->useTLS) {
-				a.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
-			}
-			if (server->GetPACSUser() != "") {
-				a.SetUserPass(server->GetPACSUser(), server->GetPACSPass());
-			}
-			a.QueryServer(&query, server, pModelo, localAET, CT_FindSeries);
-
-			return pModelo;
-		}
-
-		IModeloDicom* PACSController::BuscarImagenes(
-			void* connectionKey,
-			const std::string& serverId,
-			const std::string& idSerie,
-			const std::string& /*idImagen*/,
-			IModeloDicom* pModelo,
-			GNC::IProxyNotificadorProgreso* pNotificador
-			)
-		{
-			DicomServerList* listaServidores = DicomServerList::Instance();
-			GNC::GCS::Ptr<DicomServer> server = listaServidores->GetServer(serverId);
-
-			wxCSConv conv = GetConv(server->GetDefaultCharset());
-
-			std::string serieId;
-
-			if (!idSerie.empty()) {
-				serieId = idSerie;
-			}
-
-			DcmDataset query;
-			DcmElement* e = NULL;
-
-			e = newDicomElement(DCM_SpecificCharacterSet);
-			e->putString(server->GetDefaultCharset().c_str());
-			query.insert(e);
-
-			e = newDicomElement(DCM_QueryRetrieveLevel);
-			e->putString(wxString( "IMAGE", wxConvUTF8).mb_str(conv));
-			query.insert(e);
-
-			e = newDicomElement(DCM_SeriesInstanceUID);
-			e->putString(wxString( serieId.c_str(), wxConvUTF8).mb_str(conv));
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_SOPInstanceUID);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_ImageID);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_ImageIndex);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			e = newDicomElement(DCM_ReferringPhysicianName);
-			if (query.insert(e).bad()) {
-				delete e;
-			}
-
-			NetClient<FindAssociation> a(connectionKey, "C-FIND", pNotificador);
-
-			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
-
-			if (server->useTLS) {
-				a.SetTLS(server->GetCertificate(), server->GetPrivateKey(), server->GetverifyCredentials());
-			}
-			if (server->GetPACSUser() != "") {
-				a.SetUserPass(server->GetPACSUser(), server->GetPACSPass());
-			}
-			a.QueryServer(&query, server, pModelo, localAET, CT_FindImagenes);
-
-			return pModelo;
-		}
-
 		bool PACSController::LeerDicomDir(const std::string& pathDicomDir, IModeloDicom* pModelo)
 		{
 			if(pModelo == NULL || !DICOMManager::EsDicom(pathDicomDir))
@@ -1681,16 +1291,15 @@ namespace GIL {
 				fp = fopen(filePath.c_str(), "wb");
 				curl_easy_setopt(http_handle, CURLOPT_URL, url.c_str());					
 				//proxy settings
-				wxProxySettings settings;
-				settings.ProxySettingsLoadGeneral();
-				if (settings.m_bUseProxy) {
-					curl_easy_setopt(http_handle, CURLOPT_PROXY, std::string(settings.m_strProxyHostname.ToUTF8()).c_str());
-					curl_easy_setopt(http_handle, CURLOPT_PROXYPORT, settings.m_nProxyPort);
-					if (settings.m_bRequiresAuth) {
-						curl_easy_setopt(http_handle, CURLOPT_PROXYUSERNAME,std::string(settings.m_strProxyUsername.ToUTF8()).c_str());
-						curl_easy_setopt(http_handle, CURLOPT_PROXYPASSWORD, std::string(settings.m_strProxyPassword.ToUTF8()).c_str());
+				GNC::GCS::ProxySettings settings = GNC::GCS::ConfigurationController::Instance()->GetProxySettings();
+				if (settings.useProxy) {
+					curl_easy_setopt(http_handle, CURLOPT_PROXY, settings.hostName.c_str());
+					curl_easy_setopt(http_handle, CURLOPT_PROXYPORT, settings.port);
+					if (settings.requiresAuth) {
+						curl_easy_setopt(http_handle, CURLOPT_PROXYUSERNAME, settings.userName.c_str());
+						curl_easy_setopt(http_handle, CURLOPT_PROXYPASSWORD, settings.password.c_str());
 					}
-					curl_easy_setopt(http_handle, CURLOPT_NOPROXY, std::string(settings.m_strProxyExceptions.ToUTF8()).c_str());
+					curl_easy_setopt(http_handle, CURLOPT_NOPROXY, settings.exceptions.c_str());
 				}
 				//progress
 				curl_easy_setopt(http_handle, CURLOPT_PROGRESSDATA , pNotifier);
@@ -1725,9 +1334,7 @@ namespace GIL {
 		bool PACSController::Query(
 			void* connectionKey,
 			const std::string& abstractSyntax,
-			const std::list<std::string>& /*transferSyntaxes*/,
 			const GIL::DICOM::DicomDataset& queryWrapper,
-			int maxResultTagLen,
 			std::list< GNC::GCS::Ptr<GIL::DICOM::DicomDataset> >& resultsWrapper,				
 			const std::string& serverId,
 			GNC::IProxyNotificadorProgreso* pNotificador
@@ -1746,9 +1353,7 @@ namespace GIL {
 			e->putString(server->GetDefaultCharset().c_str());
 			query.insert(e);
 
-			DICOMManager* dm = new DICOMManager(&query, server->GetDefaultCharset());
-			dm->InsertarJerarquia(queryWrapper, NULL, NULL);
-			delete dm;
+			FillInQuery(queryWrapper, &query, server);
 
 			std::string localAET = GNC::Entorno::Instance()->GetDicomLocalAET();
 
@@ -1762,26 +1367,8 @@ namespace GIL {
 			if (server->GetPACSUser() != "") {
 				a.SetUserPass(server->GetPACSUser(), server->GetPACSPass());
 			}
-			if (a.QueryServer(&query, server, NULL, localAET, CT_None)) {
-				DcmStack* stack = a.GetResultStack();
-				if (stack != NULL)
-				{
-
-					for (unsigned int i = 0; i < stack->card(); i++) {
-
-						if (stack->elem(i)->ident() == EVR_dataset) {
-							GIL::DICOM::DICOMManager mgr( static_cast<DcmDataset*>(stack->elem(i)), server->GetDefaultCharset() );
-							GNC::GCS::Ptr<GIL::DICOM::DicomDataset> base = new GIL::DICOM::DicomDataset();							
-							mgr.CargarJerarquia((*base), maxResultTagLen);
-							resultsWrapper.push_back(base);
-						}
-					}
-				}
-				return true;
-			}
-			else {
-				return false;
-			}
+			
+			return a.QueryServer(&query, server, resultsWrapper, localAET);
 		}
 
 
@@ -1796,25 +1383,11 @@ namespace GIL {
 			std::string strTmp;
 			if(base.getTag("0008|0052", strTmp)) {
 				if (strTmp == "STUDY") {
-					std::string uidEstudio, accNumber;
-					base.getTag("0020|000d", uidEstudio);
-					base.getTag("0008|0050", accNumber);
-					if (accNumber == "" && uidEstudio == "") {
-						throw GIL::DICOM::PACSException(_Std("You have to specify at least uid study or accession number"));
-					}
-
 					ObtenerEstudio(connectionKey, serverId, base, pModelo, pNotificador, link);
 				} else if (strTmp == "SERIES") {
 					std::string uidSeries;
-					if (!base.getTag("0020|000e",uidSeries)) {
-						throw GIL::DICOM::PACSException(_Std("You have to specify at least uid series"));
-					}
 					ObtenerSerie(connectionKey, serverId, base, pModelo, pNotificador, link);
 				} else if (strTmp == "IMAGE")  {
-					std::string uidImage;
-					if (!base.getTag("0008|0018",uidImage)) {
-						throw GIL::DICOM::PACSException(_Std("You have to specify uid series"));
-					}
 					ObtenerImagen(connectionKey, serverId, base, pModelo, pNotificador);
 				} else  {
 					throw GIL::DICOM::PACSException(_Std("Unknown query/retrieve level"));
@@ -1837,16 +1410,15 @@ namespace GIL {
 			if (http_handle) {
 				curl_easy_setopt(http_handle, CURLOPT_URL, url.c_str());					
 				//proxy settings
-				wxProxySettings settings;
-				settings.ProxySettingsLoadGeneral();
-				if (settings.m_bUseProxy) {
-					curl_easy_setopt(http_handle, CURLOPT_PROXY, std::string(settings.m_strProxyHostname.ToUTF8()).c_str());
-					curl_easy_setopt(http_handle, CURLOPT_PROXYPORT, settings.m_nProxyPort);
-					if (settings.m_bRequiresAuth) {
-						curl_easy_setopt(http_handle, CURLOPT_PROXYUSERNAME,std::string(settings.m_strProxyUsername.ToUTF8()).c_str());
-						curl_easy_setopt(http_handle, CURLOPT_PROXYPORT, std::string(settings.m_strProxyPassword.ToUTF8()).c_str());
+				GNC::GCS::ProxySettings settings = GNC::GCS::ConfigurationController::Instance()->GetProxySettings();
+				if (settings.useProxy) {
+					curl_easy_setopt(http_handle, CURLOPT_PROXY, settings.hostName.c_str());
+					curl_easy_setopt(http_handle, CURLOPT_PROXYPORT, settings.port);
+					if (settings.requiresAuth) {
+						curl_easy_setopt(http_handle, CURLOPT_PROXYUSERNAME, settings.userName.c_str());
+						curl_easy_setopt(http_handle, CURLOPT_PROXYPASSWORD, settings.password.c_str());
 					}
-					curl_easy_setopt(http_handle, CURLOPT_NOPROXY, std::string(settings.m_strProxyExceptions.ToUTF8()).c_str());
+					curl_easy_setopt(http_handle, CURLOPT_NOPROXY, settings.exceptions.c_str());
 				}
 
 				curl_easy_setopt(http_handle, CURLOPT_ERRORBUFFER, curl_err);
