@@ -1,16 +1,16 @@
 /*
- *  
- *  $Id: streamingloader.h $
- *  Ginkgo CADx Project
- *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
- *  http://ginkgo-cadx.com
- *
- *  This file is licensed under LGPL v3 license.
- *  See License.txt for details
- *
- *
- */
+*  
+*  $Id: streamingloader.h $
+*  Ginkgo CADx Project
+*
+*  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
+*  http://ginkgo-cadx.com
+*
+*  This file is licensed under LGPL v3 license.
+*  See License.txt for details
+*
+*
+*/
 #pragma once
 #if defined _WINDOWS
 #pragma warning(disable : 4702)
@@ -26,7 +26,6 @@
 //region "Forward Declarations"
 
 class vtkImageData;
-class vtkImageDataStreamer;
 class vtkImageChangeInformation;
 
 namespace GNC {
@@ -50,24 +49,54 @@ namespace GNC {
 
 		virtual bool IsSignalFile() { return m_SignalFile; }
 		virtual void SetInput(const std::string& fichero);
-		virtual void Update();                                       // Actualiza la imagen completa del puerto de salida
-		virtual void UpdateInformation();                            // Actualiza la informacion del puerto de salida
-		virtual void SetCustomOrientation(GNC::GCS::Vector3D& camera_focal_point, GNC::GCS::Vector3D& camera_position, GNC::GCS::Vector3D& camera_view_up, double& rotation);
-		virtual const GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> GetDirection();                // Obtiene los cosenos directores
-		virtual void GetDimensions(int dimensions[3]);      // Obtiene las dimensiones de la imagen de entrada
-		virtual void GetOrigin(double origin[3]);                    // Obtiene el origen de la imagen de entrada
-		virtual void GetSpacing(double spacing[3]);                  // Obtiene el spacing de la imagen de entrada
-		virtual void SetOutputSpacing(double spacing[3]);            // establece el spacing de salida
-		virtual void SetOutputOrigin(double origin[3]);				 // establece el origen de salida
-		virtual void GetOutputOrigin(double origin[3]);              // Obtiene el origen de la imagen de entrada
-		virtual void GetOutputSpacing(double spacing[3]);            // Obtiene el spacing de la imagen de entrada
-		virtual int GetCurrentSliceIndex()  const;
+
+		//------------------------------------------------------------------------------------------------
+		//region IPipelineProperties realization
+
+		/** Updates **/
+		virtual void Update();
+
+		/** Updates output information **/
+		virtual void UpdateInformation();
+
+		/* Gets original (3D Volume) direction cosines */
+		virtual const GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> GetDirection();
+
+		/** Gets the original (3D Volume) origin **/
+		virtual void GetOrigin(double origin[3]);
+
+		/** Gets the original (3D Volume) spacing **/
+		virtual void GetSpacing(double spacing[3]);
+
+		/** Gets the original (3D Volume) dimensions **/
+		virtual void GetDimensions(int dims[3]);
+
+		/** Gets the slice direction cosines **/
+		virtual const GNC::GCS::Ptr<GNC::GCS::IGinkgoMatrix4x4> GetOutputDirection();
+
+		/** Gets the slice output origin **/
+		virtual void GetOutputOrigin(double origin[3]);
+
+		/** Gets the slice output spacing **/
+		virtual void GetOutputSpacing(double spacing[3]);
+
+		/** Gets the slice output dimensions **/
+		virtual void GetOutputDimensions(int currentDimensions[3]);
+
+		//endregion
+
+		/** Sets the output spacing **/
+		virtual void SetOutputSpacing(double spacing[3]);
+
+		/** Sets the output origin **/
+		virtual void SetOutputOrigin(double origin[3]);
+
 		virtual std::string GetPatientPosition();
+
 		virtual vtkSmartPointer<vtkAlgorithmOutput> GetOutputPort(); // Devuelve el puerto de salida
 		virtual void GetOutputCopy(vtkSmartPointer<vtkImageData>& output);    // Devuelve por parametro una copia de la imagen
-		virtual void GetOutputDimensions(int currentDimensions[3]);  //devuelve las dimensiones de salida
 		virtual bool GetDefaultWindowLevel(double &window, double &level);
-		
+
 	protected:
 		void CargarITK(GNC::GCS::IComando* cmd, int* orientacion, double* spacing = NULL);
 
