@@ -1,6 +1,6 @@
 /*
 *
-*  $Id: panelconfiguracionpermisos.cpp $
+*  $Id: defaultmodalitysettingsconfigurationpanel.cpp $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
@@ -35,15 +35,28 @@
 #include "defaultmodalitysettingsconfigurationpanel.h"
 #include <resources/ginkgoresourcesmanager.h>
 
-#define COL_LABEL_ID				0
-#define COL_WINDOW_ID				1
-#define COL_LEVEL_ID				2
+#define COL_LABEL_IDX				0
+#define COL_LABEL_WIDTH				100
+#define COL_WINDOW_IDX				1
+#define COL_WINDOW_WIDTH			80
+#define COL_LEVEL_IDX				2
+#define COL_LEVEL_WIDTH				80
 
 namespace GNC {
-	namespace GUI {		
-		class ModalityPanel: public ModalityPanelBase
+	namespace GUI {
+
+		class ModalityPanel : public ModalityPanelBase
 		{
+
+		private:
+
+			wxObjectDataPtr<wxDataViewListStore> m_pModel;
+			typedef std::map<std::string, ModalityPanel*> TModalityMap;
+
 		public:
+
+			
+
 			class EditCornerAnnotationsDialog: public EditCornerAnnotationsDialogBase
 			{
 			public:
@@ -159,6 +172,7 @@ namespace GNC {
 				ModalityPanel* Parent;
 				std::vector<CornerAnnotationPanel*> m_panelVector;
 			};
+
 			class AddWindowLevelDialog: public AddWLDialogBase
 			{
 			public:
@@ -202,34 +216,48 @@ namespace GNC {
 				bool EditMode;
 			};
 
-
 			ModalityPanel(wxWindow* pParent, DefaultModalitySettingsConfigurationPanel* pconfiguration, const GNC::GCS::Ptr<GNC::GCS::DefaultModalitySettings>& lo): ModalityPanelBase(pParent),
 					modSettings(lo),
 					pConfiguration(pconfiguration)
 			{
+				m_pModel = new wxDataViewListStore();
+				m_pListWL->AssociateModel(m_pModel.get());
+				m_pListWL->AppendColumn( new wxDataViewColumn( _("Label"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), COL_LABEL_IDX, COL_LABEL_WIDTH, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+				m_pListWL->AppendColumn( new wxDataViewColumn( _("Window"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), COL_WINDOW_IDX, COL_WINDOW_WIDTH, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+				m_pListWL->AppendColumn( new wxDataViewColumn( _("Level"), new wxDataViewTextRenderer( "string", wxDATAVIEW_CELL_INERT ), COL_LEVEL_IDX, COL_LEVEL_WIDTH, wxALIGN_LEFT,wxDATAVIEW_COL_SORTABLE | wxDATAVIEW_COL_RESIZABLE ));
+			
 			}
 
 			void InitPanels()
 			{
-					
-				wxTreeItemId idRoot = m_pWLList->AddRoot(wxT("Root"));
+				
+				wxVector<wxVariant> data;
+
 				for (GNC::GCS::DefaultModalitySettings::TListOfWLSettings::const_iterator it = modSettings->getWLSettings().begin(); it != modSettings->getWLSettings().end(); ++it)
 				{
-					wxTreeItemId idItem = m_pWLList->AppendItem(m_pWLList->GetRootItem(),wxString::FromUTF8((*it)->getLabel().c_str()));
-					m_pWLList->SetItemText(idItem, COL_WINDOW_ID, wxString::Format(wxT("%.2lf"), (*it)->getWindow()));
-					m_pWLList->SetItemText(idItem, COL_LEVEL_ID, wxString::Format(wxT("%.2lf"), (*it)->getLevel()));
+					const GNC::GCS::DefaultModalitySettings::TListOfWLSettings::value_type& tuple = (*it);
+					data.clear();
+
+					data.push_back(wxString::FromUTF8(tuple->getLabel().c_str()));
+					data.push_back(wxString::Format(wxT("%lf"), tuple->getWindow()));
+					data.push_back(wxString::Format(wxT("%lf"), tuple->getLevel()));
+					
+					m_pListWL->AppendItem(data);
 				}
+				
 				RebuildComboWL();
+				
 				m_pChoiceInterpolate->Append(_("Nearest neighbour"));
 				m_pChoiceInterpolate->Append(_("Linear"));
 				m_pChoiceInterpolate->Append(_("Cubic"));
+				
 				if (modSettings->getInterpolationMode() == GNC::GCS::DefaultModalitySettings::TIM_NEAREST_NEIGHBOUR) {
 					m_pChoiceInterpolate->Select(0);
 				} else if (modSettings->getInterpolationMode() == GNC::GCS::DefaultModalitySettings::TIM_LINEAR) {
 					m_pChoiceInterpolate->Select(1);
 				}  else if (modSettings->getInterpolationMode() == GNC::GCS::DefaultModalitySettings::TIM_CUBIC) {
 					m_pChoiceInterpolate->Select(2);
-				}
+				}				
 			}
 
 			void RebuildComboWL()
@@ -257,15 +285,23 @@ namespace GNC {
 
 			virtual void OnAddWL(wxCommandEvent& /*evt*/) 
 			{
+			
 				AddWindowLevelDialog dlg(this);
 				if (dlg.ShowModal() == wxID_OK) {
-					m_pDefaultWindowLevel->Append(dlg.m_pLabel->GetValue());
 
-					wxTreeItemId idItem = m_pWLList->AppendItem(m_pWLList->GetRootItem(),dlg.m_pLabel->GetValue());
-					m_pWLList->SetItemText(idItem, COL_WINDOW_ID, dlg.m_pWindow->GetValue());
-					m_pWLList->SetItemText(idItem, COL_LEVEL_ID, dlg.m_pLevel->GetValue());
+					m_pDefaultWindowLevel->Append(dlg.m_pLabel->GetValue());
+					
+					wxVector<wxVariant> data;
+
+					data.push_back(dlg.m_pLabel->GetValue());
+					data.push_back(dlg.m_pWindow->GetValue());
+					data.push_back(dlg.m_pLevel->GetValue());
+					
+					m_pModel->AppendItem(data);
+					
 					pConfiguration->OnPropiedadCambiada();
 				}
+				
 			}
 
 			virtual void OnChoiceChanged(wxCommandEvent& )
@@ -275,20 +311,29 @@ namespace GNC {
 
 			virtual void OnEditWL(wxCommandEvent& /*evt*/) 
 			{
-				wxTreeItemId item = m_pWLList->GetSelection();
-				if (item.IsOk()) {
-					wxString oldLabel = m_pWLList->GetItemText(item, COL_LABEL_ID);
-					wxString oldWindow = m_pWLList->GetItemText(item, COL_WINDOW_ID);
-					wxString oldLevel = m_pWLList->GetItemText(item, COL_LEVEL_ID);
+				
+				wxDataViewItem selection = m_pListWL->GetSelection();
+				if(selection.IsOk()){
+					wxVariant oldLabel;
+					wxVariant oldWindow;
+					wxVariant oldLevel;
+
+					m_pModel->GetValue(oldLabel, selection, COL_LABEL_IDX);
+					m_pModel->GetValue(oldWindow, selection, COL_WINDOW_IDX);
+					m_pModel->GetValue(oldLevel, selection, COL_LEVEL_IDX);					
+					
 					AddWindowLevelDialog dlg(this, oldLabel, oldWindow, oldLevel);
 					if (dlg.ShowModal() == wxID_OK) {
 						int comboItem = m_pDefaultWindowLevel->FindString(oldLabel);
 						if (comboItem > 0) {
 							m_pDefaultWindowLevel->SetString(comboItem, dlg.m_pLabel->GetValue());
 						}
-						m_pWLList->SetItemText(item, COL_LABEL_ID, dlg.m_pLabel->GetValue());
-						m_pWLList->SetItemText(item, COL_WINDOW_ID, dlg.m_pWindow->GetValue());
-						m_pWLList->SetItemText(item, COL_LEVEL_ID, dlg.m_pLevel->GetValue());
+						m_pModel->SetValue(dlg.m_pLabel->GetValue(), selection, COL_LABEL_IDX);
+						m_pModel->SetValue(dlg.m_pWindow->GetValue(), selection, COL_WINDOW_IDX);
+						m_pModel->SetValue(dlg.m_pLevel->GetValue(), selection, COL_LEVEL_IDX);
+						
+						m_pModel->ItemChanged(selection);
+
 						pConfiguration->OnPropiedadCambiada();
 					}
 				}
@@ -296,19 +341,34 @@ namespace GNC {
 
 			virtual void OnDeleteWL(wxCommandEvent& /*evt*/)
 			{
-				wxTreeItemId item = m_pWLList->GetSelection();
-				if (item.IsOk()) {
+
+				wxDataViewItem selection = m_pListWL->GetSelection();
+				if(selection.IsOk()){
 					int answer = wxMessageBox(_("Do you confirm the removal of the preset?"), _("Data modified"), wxYES_NO | wxCANCEL, this);
 					if(answer == wxYES){
-						wxString oldLabel = m_pWLList->GetItemText(item, COL_LABEL_ID);
-						int comboItem = m_pDefaultWindowLevel->FindString(oldLabel);
+						
+						wxVariant oldLabel;
+						m_pModel->GetValue(oldLabel, selection, COL_LABEL_IDX);
+						
+						int comboItem = m_pDefaultWindowLevel->FindString(oldLabel.GetString());
 						if (comboItem > 0) {
 							m_pDefaultWindowLevel->Delete(comboItem);
 							if (m_pDefaultWindowLevel->GetSelection() < 0) {
 								m_pDefaultWindowLevel->Select(0);
 							}
 						}
-						m_pWLList->Delete(item);
+						bool notFound = true;
+						for (unsigned int i = 0; notFound && i < m_pModel->GetCount(); ++i) {
+							wxDataViewItem item = m_pModel->GetItem(i);
+
+							wxVariant val2;
+							m_pModel->GetValue(val2, item, COL_LABEL_IDX);
+							if (oldLabel == val2) {
+								notFound = false;
+								m_pModel->DeleteItem(i);
+							}
+						}
+
 						pConfiguration->OnPropiedadCambiada();
 					}
 				}
@@ -328,13 +388,20 @@ namespace GNC {
 				modSettings->clearWindowLevels();
 				modSettings->setInitialWindowLevelLabel(std::string(m_pDefaultWindowLevel->GetString(m_pDefaultWindowLevel->GetSelection()).ToUTF8()));
 
-				wxTreeItemIdValue cookie;
-				for (wxTreeItemId item = m_pWLList->GetFirstChild(m_pWLList->GetRootItem(), cookie); item.IsOk(); item = m_pWLList->GetNextChild(m_pWLList->GetRootItem(), cookie))
-				{
+				for (unsigned int i = 0; i < m_pModel->GetCount(); ++i) {
+					wxDataViewItem item = m_pModel->GetItem(i);
 					double window;
 					double level;
-					if (m_pWLList->GetItemText(item, COL_WINDOW_ID).ToDouble(&window) && m_pWLList->GetItemText(item, COL_LEVEL_ID).ToDouble(&level)) {
-						GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(window, level, std::string(m_pWLList->GetItemText(item, COL_LABEL_ID).ToUTF8())));
+					wxVariant labelVal;
+					wxVariant windowVal;
+					wxVariant levelVal;
+
+					m_pModel->GetValue(labelVal, item, COL_LABEL_IDX);
+					m_pModel->GetValue(windowVal, item, COL_WINDOW_IDX);
+					m_pModel->GetValue(levelVal, item, COL_LEVEL_IDX);
+
+					if (windowVal.GetString().ToDouble(&window) && levelVal.GetString().ToDouble(&level)) {
+						GNC::GCS::Ptr<GNC::GCS::WindowLevelSetting> wlSettings(new GNC::GCS::WindowLevelSetting(window, level, std::string(labelVal.GetString().ToUTF8())));
 						modSettings->addWindowLevel(wlSettings);
 					}
 				}
@@ -351,7 +418,9 @@ namespace GNC {
 		////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 		DefaultModalitySettingsConfigurationPanel::DefaultModalitySettingsConfigurationPanel(wxWindow* pParent,IDialogoConfiguracion* pDialogo): DefaultModalitySettingsConfigurationPanelBase(pParent), IPasoConfiguracion(pDialogo)
 		{
+
 			Recargar();
+
 			wxColour barColor = wxColour(200,200,200);
 			wxFont fontBar = wxFont( 10, 70, 90, wxFONTWEIGHT_BOLD, false, wxEmptyString );
 		}
@@ -362,9 +431,10 @@ namespace GNC {
 
 		void DefaultModalitySettingsConfigurationPanel::Recargar()
 		{
+			
 			GNC::GCS::ModalitySettingsController::TMapOfModalitySettings modalitySettings = GNC::GCS::ModalitySettingsController::Instance()->getModalitySettingsMap();
 
-			m_pTreeNavigation->DeleteAllItems();
+			m_pWLList->DeleteAllItems();
 			m_currentModality = NULL;
 			for (TModalityMap::iterator it = modalityBrowser.begin(); it != modalityBrowser.end(); ++it) 
 			{
@@ -372,12 +442,12 @@ namespace GNC {
 			}
 			modalityBrowser.clear();
 			//default modality settings...
-			wxTreeItemId root = m_pTreeNavigation->AddRoot(_("Modalities"));
+			wxTreeItemId root = m_pWLList->AddRoot(_("Modalities"));
 			for (GNC::GCS::ModalitySettingsController::TMapOfModalitySettings::const_iterator it = modalitySettings.begin(); it != modalitySettings.end(); ++it)
 			{
 				if ((*it).second.IsValid()) {
 					ModalityPanel * mp = new ModalityPanel(m_pModalityPanel, this, (*it).second);
-					wxTreeItemId id = m_pTreeNavigation->AppendItem(root, wxString::FromUTF8(mp->getModalityName().c_str()));
+					wxTreeItemId id = m_pWLList->AppendItem(root, wxString::FromUTF8(mp->getModalityName().c_str()));
 					modalityBrowser[id.m_pItem] = mp;
 					mp->InitPanels();
 					mp->Hide();
@@ -386,9 +456,9 @@ namespace GNC {
 				}
 			}
 			wxTreeItemIdValue cookie;
-			m_pTreeNavigation->SelectItem(m_pTreeNavigation->GetFirstChild(root, cookie));
+			m_pWLList->SelectItem(m_pWLList->GetFirstChild(root, cookie));
 			LoadCurrent();
-			//
+			//*/
 			Layout();
 		}
 
@@ -430,13 +500,13 @@ namespace GNC {
 		//endregion
 
 
-		void DefaultModalitySettingsConfigurationPanel::OnNavigationChanged(wxTreeEvent &){
+		void DefaultModalitySettingsConfigurationPanel::OnTreeSelChanged(wxTreeEvent &){
 			LoadCurrent();
 		}
 
 		void DefaultModalitySettingsConfigurationPanel::LoadCurrent() 
 		{
-			wxTreeItemId id = m_pTreeNavigation->GetSelection();
+			wxTreeItemId id = m_pWLList->GetSelection();
 			if (id.IsOk()) {
 				if(modalityBrowser.find(id.m_pItem) != modalityBrowser.end()){
 					ModalityPanel* pCurrent = modalityBrowser[id.m_pItem];
