@@ -137,7 +137,12 @@ void GNC::GUI::PanelConfiguracionHCE::OnTestClick(wxCommandEvent &)
 
 		if (!ep) {
 			std::stringstream ostr;
-			ostr << _Std("Error connecting to url") << std::string(" ") << url;
+			if (url.empty() || url.at(url.size() - 1) == ':' ) {
+				ostr << _Std("Error connecting to url") << std::string(": ") << _Std("hostname/port not set");
+			}
+			else {
+				ostr << _Std("Error connecting to url") << std::string(" ") << url;
+			}
 			wxMessageBox(wxString::FromUTF8(ostr.str().c_str()), _("Connection test fail"), wxICON_ERROR, this);
 		} else {
 			wxMessageBox(_("Connection test successful"),_("Info"),wxOK | wxICON_INFORMATION, this);
