@@ -49,8 +49,8 @@ namespace GNC {
 		PanelConfigurationAnonymization::PanelConfigurationAnonymization(wxWindow* pParent, IDialogoConfiguracion* pDialogo): PanelConfigurationAnonymizationBase(pParent), IPasoConfiguracion(pDialogo)
 		{
 			GNC::GCS::AnonymizationController::TAnonymizationMap map = GNC::GCS::AnonymizationController::GetAnonymizationMap();
-
-	/*		m_pTagsDicom->SetColumnCount(2);
+			/*
+			m_pTagsDicom->SetColumnCount(2);
 			m_pTagsDicom->MakeColumnEditable(1, true);
 			m_pTagsDicom->SetColumnProportion(0, 3);
 			m_gridPermisos->SetColumnProportion(1, 1);
@@ -66,7 +66,8 @@ namespace GNC {
 					prop->SetCell(2, new wxPGCell( wxString::FromUTF8( ((*it).second.valorPorDefecto).c_str())) );
 					prop->SetCell(3, new wxPGCell( _("Default value") ));
 				}
-			}*/
+			}
+			*/
 		}
 
 		PanelConfigurationAnonymization::~PanelConfigurationAnonymization()
