@@ -154,10 +154,12 @@ namespace GNC {
 				// Populate Accno
 				if (GNC::GCS::IControladorPermisos::Instance()->Get("core.importacion", "input_accno").Activo()) {
 					SetStringField(tagsDicom, "0008|0050", m_pAccessionNumber);
-					m_pExtra->Show();
+					m_pAccessionNumber->Show();
+					m_pLabelAccNumber->Show();
+				} else {
+					m_pAccessionNumber->Hide();
+					m_pLabelAccNumber->Hide();
 				}
-
-
 			}
 			m_pSeriesPanel->Show(seriesDescription);
 			m_panelStudyDetails->Layout();
@@ -384,7 +386,7 @@ namespace GNC {
 		}
 
 		void GeneralData::GetAccno() {
-			if (m_pExtra->IsShown()) {
+			if (m_pAccessionNumber->IsShown()) {
 				m_pImportData->baseImages.tags["0008|0050"] = std::string(m_pAccessionNumber->GetValue().ToUTF8());
 			}
 		}
