@@ -53,7 +53,6 @@ namespace GNC {
 			m_pModeloIntegracion = pModeloIntegracion;
 
 			m_pControladorModulo = NULL;
-			m_OK = false;
 			
 			//si hay mas de un modulo con importador disponible habra que seleccionar el modulo...
 			int soportanImportacion=0;
@@ -247,7 +246,7 @@ namespace GNC {
 				for(ListaPasos::iterator it=m_ListaPasos.begin();it!=m_ListaPasos.end();++it){
 					(*it)->OnCancelled();
 				}
-				Close();
+				EndModal(wxCANCEL);
 			}
 		}
 		
@@ -300,12 +299,11 @@ namespace GNC {
 					}
 					
 					if(m_currentPaso==m_ListaPasos.end()){
-						m_OK=true;
 						if (GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions","auto_close")) {
 							GNC::GUI::StatusBarProgreso* statusBar = (GNC::GUI::StatusBarProgreso*)GNC::Entorno::Instance()->GetVentanaPrincipal()->GetStatusBar();
 							statusBar->ShowProgressDialog(true);
 						}
-						Close();
+						EndModal(wxOK);
 					}else{
 						CargarCurrent();
 					}
@@ -332,27 +330,22 @@ namespace GNC {
 		
 		void wxWizardImportacionGinkgo::OnClose(wxCloseEvent &event)
 		{
-			if(m_pModeloIntegracion.IsValid() && !m_OK)
+			if(m_pModeloIntegracion.IsValid())
 			{
 				int answer = wxMessageBox(_("Are you sure you want to cancel the import process?"),_("Cancel"), wxYES_NO ,this);
 				if(answer == wxYES)
 				{
-					m_OK = false;
 					BorrarArchivosTemporales();					
-					event.Skip(true);
+					EndModal(wxCANCEL);
 				} else {
 					event.Skip(false);
 				}
 			} else {
-				BorrarArchivosTemporales();
-				event.Skip(true);
+				BorrarArchivosTemporales();				
+				EndModal(wxCANCEL);
 			}
 		}
 		
-		bool wxWizardImportacionGinkgo::IsOK()
-		{
-			return m_OK;
-		}
 		
 		//devuelve la ruta del directorio temporal
 		std::list<std::string> wxWizardImportacionGinkgo::GetRuta()
@@ -373,7 +366,7 @@ namespace GNC {
 				pCurrent->Show(true);
 				m_pSizerPrincipal->Add(pCurrent, 10, wxEXPAND);
 
-				wxString label= wxString::Format(_("Step %d of %d: "),m_currentPasoIndex,m_ListaPasos.size());
+				wxString label= wxString::Format(_("Step %d of %d: "), (int) m_currentPasoIndex, (int) m_ListaPasos.size());
 				m_pHeader->SetTitle(label+wxString::FromUTF8((*m_currentPaso)->GetTitle().c_str()));
 				m_pBSiguiente->Enable((*m_currentPaso)->Siguiente());
 				m_pBAnterior->Enable((*m_currentPaso)->Anterior());
