@@ -153,6 +153,32 @@ public:
 #endif
 ///////////
 
+class wxGinkgoAuiNoteBook: public wxAuiNotebook
+{
+public:
+	wxGinkgoAuiNoteBook(): wxAuiNotebook()
+	{ }
+
+    wxGinkgoAuiNoteBook(wxWindow* parent,
+                  wxWindowID id = wxID_ANY,
+                  const wxPoint& pos = wxDefaultPosition,
+                  const wxSize& size = wxDefaultSize,
+				  long style = wxAUI_NB_DEFAULT_STYLE): wxAuiNotebook(parent, id, pos, size, style)
+    { 
+    }
+
+    virtual ~wxGinkgoAuiNoteBook()
+	{
+	}
+	//hack to expose this method
+	virtual wxAuiTabCtrl* GetActiveTabCtrl()
+	{
+		return wxAuiNotebook::GetActiveTabCtrl();
+	}
+};
+
+////
+
 
 EventoProgreso::EventoProgreso(TipoProgreso tipo, long threadId)
 {
@@ -183,7 +209,7 @@ EVT_CLOSE(VentanaPrincipal::OnWindowClose)
 EVT_MENU(ID_Inicio_Aplicacion, VentanaPrincipal::OnInicioAplicacion)
 END_EVENT_TABLE()
 
-VentanaPrincipal::VentanaPrincipal(wxWindow* pParent, const wxString& title) : VentanaPrincipalBase(pParent, wxID_ANY, title), m_mgr(m_pPanelCentral, AUI_NAMESPACE wxAUI_MGR_ALLOW_FLOATING | AUI_NAMESPACE  wxAUI_MGR_TRANSPARENT_DRAG |AUI_NAMESPACE  wxAUI_MGR_VENETIAN_BLINDS_HINT ),
+VentanaPrincipal::VentanaPrincipal(wxWindow* pParent, const wxString& title) : VentanaPrincipalBase(pParent, wxID_ANY, title), m_mgr(m_pPanelCentral, wxAUI_MGR_ALLOW_FLOATING | wxAUI_MGR_TRANSPARENT_DRAG | wxAUI_MGR_VENETIAN_BLINDS_HINT ),
 	StartupView(NULL)
 {
 	//load attributes
@@ -226,7 +252,7 @@ VentanaPrincipal::VentanaPrincipal(wxWindow* pParent, const wxString& title) : V
 
 	{
 		wxString wxCaption = _("Tasks");
-		AUI_NAMESPACE wxAuiPaneInfo pi(AUI_NAMESPACE wxAuiPaneInfo().Caption(wxCaption).Float().BestSize(400,170).MinSize(200,100).Resizable(true).CloseButton(true).Show(false));
+		wxAuiPaneInfo pi(wxAuiPaneInfo().Caption(wxCaption).Float().BestSize(400,170).MinSize(200,100).Resizable(true).CloseButton(true).Show(false));
 		pi.DestroyOnClose(false);
 		m_mgr.AddPane(pStatusBar->m_pPanelTareas, pi);
 	}
@@ -234,26 +260,21 @@ VentanaPrincipal::VentanaPrincipal(wxWindow* pParent, const wxString& title) : V
 	GNC::CommandController::Instance()->RegistrarProgreso(pStatusBar);
 	Connect(wxEVT_PROGRESO, EventoProgresoFunctionHandler(VentanaPrincipal::OnComando), NULL, this);
 
-	m_pNoteBook = new AUI_NAMESPACE wxAuiNotebook(m_pPanelCentral, wxID_ANY,wxDefaultPosition,
+	m_pNoteBook = new wxGinkgoAuiNoteBook(m_pPanelCentral, wxID_ANY,wxDefaultPosition,
 												  wxDefaultSize,
-												  AUI_NAMESPACE wxAUI_NB_TAB_SPLIT |  AUI_NAMESPACE wxAUI_NB_TAB_MOVE | AUI_NAMESPACE wxAUI_NB_SCROLL_BUTTONS | AUI_NAMESPACE wxAUI_NB_WINDOWLIST_BUTTON | AUI_NAMESPACE wxAUI_NB_CLOSE_ON_ALL_TABS | wxEXPAND );
-	m_pNoteBook->SetBackgroundColour(wxColour(180, 180, 180));
+												  wxAUI_NB_TAB_SPLIT |  wxAUI_NB_TAB_MOVE | wxAUI_NB_SCROLL_BUTTONS | wxAUI_NB_WINDOWLIST_BUTTON | wxAUI_NB_CLOSE_ON_ALL_TABS | wxEXPAND );
+	m_pNoteBook->SetBackgroundColour(wxColour(0, 0, 0));
 	m_pNoteBook->Connect( wxEVT_CHILD_FOCUS, wxChildFocusEventHandler( VentanaPrincipal::OnNotebookFocus ) );
-	m_pNoteBook->Connect( wxEVT_ERASE_BACKGROUND, wxEraseEventHandler( VentanaPrincipal::OnNoteBookEraseBackground ) );
 
-	m_mgr.AddPane(m_pNoteBook, AUI_NAMESPACE wxAuiPaneInfo().Name(wxT("vistas")).CenterPane().Layer(0).PaneBorder(true).Movable(false).Floatable(false).Dockable(false).LeftDockable(false).RightDockable(false).TopDockable(false).BottomDockable(false).CloseButton(false).Hide());
+	m_mgr.AddPane(m_pNoteBook, wxAuiPaneInfo().Name(wxT("vistas")).CenterPane().Layer(0).PaneBorder(true).Movable(false).Floatable(false).Dockable(false).LeftDockable(false).RightDockable(false).TopDockable(false).BottomDockable(false).CloseButton(false).Hide());
 	//
 
-
-
 	wxString wxCaption;
 	m_mgr.Update();
 
 
 	//hay que conectarlo al auimanager, porque el notebook delega el procesado de eventos al auimanager
 	{
-		AUI_USE_NAMESPACE()
-
 		m_mgr.Connect(wxEVT_COMMAND_AUINOTEBOOK_PAGE_CLOSE, wxAuiNotebookEventHandler(VentanaPrincipal::OnNotebookPageClose),NULL,this);
 		m_mgr.Connect(wxEVT_COMMAND_AUINOTEBOOK_PAGE_CHANGING, wxAuiNotebookEventHandler(VentanaPrincipal::OnNotebookPageChanging), NULL, this);
 		m_mgr.Connect(wxEVT_COMMAND_AUINOTEBOOK_PAGE_CHANGED, wxAuiNotebookEventHandler(VentanaPrincipal::OnNotebookPageChanged),NULL,this);
@@ -283,9 +304,8 @@ VentanaPrincipal::~VentanaPrincipal()
 	GNC::GUI::VentanaControlLogs::CerrarSiAbierta();
 
 	{
-		AUI_USE_NAMESPACE()
-		m_mgr.Disconnect(wxEVT_COMMAND_AUINOTEBOOK_PAGE_CLOSE, AUI_NAMESPACE wxAuiNotebookEventHandler(VentanaPrincipal::OnNotebookPageClose),NULL,this);
-		m_mgr.Disconnect(m_pNoteBook->GetId(), wxEVT_COMMAND_AUINOTEBOOK_PAGE_CHANGED, AUI_NAMESPACE wxAuiNotebookEventHandler(VentanaPrincipal::OnNotebookPageChanged),NULL,this);
+		m_mgr.Disconnect(wxEVT_COMMAND_AUINOTEBOOK_PAGE_CLOSE, wxAuiNotebookEventHandler(VentanaPrincipal::OnNotebookPageClose),NULL,this);
+		m_mgr.Disconnect(m_pNoteBook->GetId(), wxEVT_COMMAND_AUINOTEBOOK_PAGE_CHANGED, wxAuiNotebookEventHandler(VentanaPrincipal::OnNotebookPageChanged),NULL,this);
 	}
 
 
@@ -299,8 +319,6 @@ VentanaPrincipal::~VentanaPrincipal()
 	this->Disconnect( wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnControlLogs ) );
 	this->Disconnect( wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnAcercaDe ) );
 	this->Disconnect( wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnPantallaCompleta ) );
-	this->Disconnect( wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnMosaicoHorizontal ) );
-	this->Disconnect( wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnMosaicoVertical ) );
 	this->Disconnect( wxID_ANY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnMosaicoRestaurar ) );
 
 	//delete history tools
@@ -720,13 +738,11 @@ void VentanaPrincipal::OnMenuCerrarTabClick(wxCommandEvent& )
 		if(pVentana != NULL) {
 			if(m_pNoteBook->GetPageIndex(pVentana) >= 0 && m_pNoteBook->GetSelection()!=-1)
 			{
-				#if defined(USE_PATCHED_LIBS)
-				AUI_NAMESPACE wxAuiNotebookEvent evt(wxEVT_COMMAND_AUINOTEBOOK_BUTTON, m_pNoteBook->GetSelection());
+				wxAuiNotebookEvent evt(wxEVT_COMMAND_AUINOTEBOOK_BUTTON, m_pNoteBook->GetSelection());
 				evt.SetInt(wxAUI_BUTTON_CLOSE);
 				evt.SetId(5380+500);
-				evt.SetEventObject(m_pNoteBook->GetActiveTabCtrl());
+				evt.SetEventObject(((wxGinkgoAuiNoteBook*)m_pNoteBook)->GetActiveTabCtrl());
 				m_pNoteBook->GetEventHandler()->ProcessEvent(evt);
-				#endif
 			}
 		}
 	}
@@ -760,18 +776,16 @@ void VentanaPrincipal::OnMenuCerrarTodosTabsClick(wxCommandEvent& )
 //devuelve bool si ha cerrado todos
 bool VentanaPrincipal::CerrarTodosLosTabsYPanelGrids() {
 	bool todosCerrados = false;
-	#if defined(USE_PATCHED_LIBS)
 	unsigned int pestanias = m_pNoteBook->GetPageCount();
 	//la segunda condicion es para que si das a cancelar pues pare	
 	while(m_pNoteBook->GetPageCount() > 0 && pestanias == m_pNoteBook->GetPageCount()){
-		AUI_NAMESPACE wxAuiNotebookEvent evt(wxEVT_COMMAND_AUINOTEBOOK_BUTTON, m_pNoteBook->GetSelection());
+		wxAuiNotebookEvent evt(wxEVT_COMMAND_AUINOTEBOOK_BUTTON, m_pNoteBook->GetSelection());
 		evt.SetInt(wxAUI_BUTTON_CLOSE);
 		evt.SetId(5380+500);
-		evt.SetEventObject(m_pNoteBook->GetActiveTabCtrl());
+		evt.SetEventObject(((wxGinkgoAuiNoteBook*)m_pNoteBook)->GetActiveTabCtrl());
 		m_pNoteBook->GetEventHandler()->ProcessEvent(evt);
 		pestanias --;
 	}
-	#endif
 
 	if(m_pNoteBook->GetPageCount() == 0) {
 		//se cierran los paneles tabs...
@@ -906,7 +920,9 @@ void VentanaPrincipal::ShowStartUp(bool show)
 		m_mgr.GetPane(StartupView->GetWindow()).Show(show);
 		update = true;
 	}
-	GNC::GCS::ControladorVistas::Instance()->SolicitarActivarVista(StartupView);
+	if (show) {
+		GNC::GCS::ControladorVistas::Instance()->SolicitarActivarVista(StartupView);
+	}
 	if (m_pNoteBook->IsShown() == show) {
 		m_mgr.GetPane(m_pNoteBook).Show(!show);
 		update = true;
@@ -917,45 +933,6 @@ void VentanaPrincipal::ShowStartUp(bool show)
 	}
 }
 
-void VentanaPrincipal::OnMosaicoHorizontal(wxCommandEvent& )
-{
-#if defined (_WINDOWS)
-	wxWindowDisabler dis;
-#endif
-	SuperFreeze();
-	ReplegarPestanias();
-	#if defined(USE_PATCHED_LIBS)
-	if(m_pNoteBook->GetPageCount() > 1 ){
-		int posicionCorte = m_pNoteBook->GetSize().y/m_pNoteBook->GetPageCount();		
-		for( unsigned int idx = 0; idx < m_pNoteBook->GetPageCount(); idx++){
-			m_pNoteBook->CustomSplit(idx,wxTOP,posicionCorte);
-		}
-	}
-	#endif
-	m_mgr.Update();
-	SuperThaw();
-}
-
-void VentanaPrincipal::OnMosaicoVertical(wxCommandEvent& )
-{
-	#if defined (_WINDOWS)
-	wxWindowDisabler dis;
-	#endif
-	SuperFreeze();
-	ReplegarPestanias();
-	#if defined(USE_PATCHED_LIBS)
-	if(m_pNoteBook->GetPageCount() > 1 ){
-		//la posicion de corte sera el tamanio x del notebook entre el numero de tabs
-		int posicionCorte = m_pNoteBook->GetSize().x/m_pNoteBook->GetPageCount();
-		for( unsigned int idx = 0; idx < m_pNoteBook->GetPageCount(); idx++){
-			m_pNoteBook->CustomSplit(idx,wxLEFT,posicionCorte);
-		}
-	}
-	#endif
-	m_mgr.Update();
-	SuperThaw();
-}
-
 void VentanaPrincipal::OnMosaicoRestaurar(wxCommandEvent& )
 {
 	wxWindowDisabler disabler;
@@ -1041,8 +1018,9 @@ void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &)
 				continue;
 			}
 			#endif
-			
-			pathOfFile = param;
+			if (!param.StartsWith("--")) {
+				pathOfFile = param;
+			}
 		}
 	}
 
@@ -1081,8 +1059,6 @@ void VentanaPrincipal::OnInicioAplicacion(wxCommandEvent &)
 	} else {
 		Login();
 	}
-	
-	GNC::GUI::HistoryPanel3::Instance()->checkPendingTasks();
 }
 
 void VentanaPrincipal::EjecutarParametro(const wxString cadena, bool doLogin)
@@ -1285,8 +1261,6 @@ void VentanaPrincipal::RefrescarMenus()
 	//se vacía la barra y se borran los menus que se crearon en la anterior pasada
     wxWindowDisabler dis;
     SuperFreeze();
-	while (m_pMenuBar->GetMenuCount() > 0)
-		delete m_pMenuBar->Remove(0);
 
 	wxMenu* pMenuArchivo = new wxMenu();
 	wxMenu* pMenuEdicion = new wxMenu();
@@ -1329,36 +1303,23 @@ void VentanaPrincipal::RefrescarMenus()
 		//view
 		{
 			wxMenuItem*  pPantallaCompleta = new wxMenuItem( pMenuVer, ID_PANTALLA_COMPLETA, wxString(_("Full screen"))+ wxT("\tF11"), _("Show full screen"), wxITEM_NORMAL );
-			wxMenu* subMenuPestanias = new wxMenu();
-			wxMenuItem* pMosaicoRestaurar = new wxMenuItem(subMenuPestanias, ID_MOSAICO_RESTAURAR, wxString( _("Tab grouping") ), _("Tab grouping"), wxITEM_NORMAL );
-			wxMenuItem*  pMosaicoHorizontal = new wxMenuItem( subMenuPestanias, ID_MOSAICO_HORIZONTAL, _("Horizontal mosaic"), _("Horizontal mosaic"), wxITEM_NORMAL );
-			wxMenuItem*  pMosaicoVertical = new wxMenuItem( subMenuPestanias, ID_MOSAICO_VERTICAL, _("Vertical mosaic"), _("Vertical mosaic"), wxITEM_NORMAL );
+			wxMenuItem* pMosaicoRestaurar = new wxMenuItem(pMenuVer, ID_MOSAICO_RESTAURAR, wxString( _("Tab grouping") ), _("Tab grouping"), wxITEM_NORMAL );
 
 			#ifdef __WXMSW__
 			pMosaicoRestaurar->SetBitmaps(GinkgoResourcesManager::MenuTabs::GetIcoReagrupar());
-			#else
-			pMosaicoRestaurar->SetBitmap(GinkgoResourcesManager::MenuTabs::GetIcoReagrupar());
-			#endif
-
-			subMenuPestanias->Append(pMosaicoRestaurar);
-			subMenuPestanias->AppendSeparator();
-			subMenuPestanias->Append(pMosaicoHorizontal);
-			subMenuPestanias->Append(pMosaicoVertical);
-
-			#ifdef __WXMSW__
 			pPantallaCompleta->SetBitmaps(GinkgoResourcesManager::MenuIcons::GetIcoPantallaCompleta());
 			#else
+			pMosaicoRestaurar->SetBitmap(GinkgoResourcesManager::MenuTabs::GetIcoReagrupar());
 			pPantallaCompleta->SetBitmap(GinkgoResourcesManager::MenuIcons::GetIcoPantallaCompleta());
 			#endif
 			pMenuVer->Append( pPantallaCompleta );
 			pMenuVer->AppendSeparator();
+			pMenuVer->Append(pMosaicoRestaurar);
 
-			pMenuVer->AppendSubMenu(subMenuPestanias,_("Tabbed organization"));
+			//image
 			InsertToolsFromFamily(pMenuVer, GNC::GCS::ITool::TMenuVer);
 
 			this->Connect( pPantallaCompleta->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnPantallaCompleta ) );
-			this->Connect( pMosaicoHorizontal->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnMosaicoHorizontal ) );
-			this->Connect( pMosaicoVertical->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnMosaicoVertical ) );
 			this->Connect( pMosaicoRestaurar->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnMosaicoRestaurar ) );
 		}
 
@@ -1428,14 +1389,18 @@ void VentanaPrincipal::RefrescarMenus()
 		this->Connect( pMenuHL7->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnMensajesHL7 ) );
 		this->Connect( pMenuLogs->GetId(), wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( VentanaPrincipal::OnControlLogs ) );
 	}
-
+	//avoid hide bar => flickering!!
+	m_pMenuBar->Freeze();
 	m_pMenuBar->Append( pMenuArchivo, _("&File") );
+	while (m_pMenuBar->GetMenuCount() > 1)
+		delete m_pMenuBar->Remove(0);	
 	m_pMenuBar->Append( pMenuEdicion, _("&Edit") );
 	m_pMenuBar->Append( pMenuVer, _("View") );
 	m_pMenuBar->Append( pMenuSeries, _("Series") );
 	m_pMenuBar->Append( pMenuHerramientas, _("Tools") );
 	m_pMenuBar->Append( pMenuAyuda, _("&Help") );
 	
+	m_pMenuBar->Thaw();
 	this->SetMenuBar(m_pMenuBar);
 
 #ifdef __WXMAC__
@@ -1494,7 +1459,7 @@ void VentanaPrincipal::CargarHistorial()
 	study->Module = NULL;
 	study->ParentWindow = m_pPanelCentral;
 	StartupView = new GNC::GUI::StartUpView(study);
-	m_mgr.AddPane(StartupView->GetWindow(), AUI_NAMESPACE wxAuiPaneInfo().Name(_("Mosaic")).CenterPane().Layer(0).PaneBorder(true).Movable(false).Floatable(false).Dockable(false).LeftDockable(false).RightDockable(false).TopDockable(false).BottomDockable(false).CloseButton(false));
+	m_mgr.AddPane(StartupView->GetWindow(), wxAuiPaneInfo().Name(_("Mosaic")).CenterPane().Layer(0).PaneBorder(true).Movable(false).Floatable(false).Dockable(false).LeftDockable(false).RightDockable(false).TopDockable(false).BottomDockable(false).CloseButton(false));
 	
 	GNC::GCS::Ptr<GIL::IModeloIntegracion> ptr;
 	GNC::Entorno::Instance()->GetControladorCarga()->CargaAsincrona(StartupView, false);
@@ -1543,7 +1508,7 @@ void VentanaPrincipal::OnNotebookPageChanging(wxAuiNotebookEvent& /*event*/)
 }
 
 
-void VentanaPrincipal::OnNotebookPageChanged(AUI_NAMESPACE wxAuiNotebookEvent& event)
+void VentanaPrincipal::OnNotebookPageChanged(wxAuiNotebookEvent& event)
 {
 	SuperFreeze();
 	if (m_pNoteBook->GetPageCount() == 0) { // Se han eliminado todas las paginas
@@ -1552,7 +1517,7 @@ void VentanaPrincipal::OnNotebookPageChanged(AUI_NAMESPACE wxAuiNotebookEvent& e
 	else
 	{ // Se ha cambiado de pagina
 		ShowStartUp(false);
-		GNC::GCS::IVista* v  = GNC::GCS::ControladorVistas::Instance()->ObtenerVistaRegistrada(m_pNoteBook->GetPage(event.selection));
+		GNC::GCS::IVista* v  = GNC::GCS::ControladorVistas::Instance()->ObtenerVistaRegistrada(m_pNoteBook->GetPage(event.GetSelection()));
 		if (v != NULL) {
 			GNC::GCS::ControladorVistas::Instance()->SolicitarActivarVista(v);
 		}
@@ -1561,7 +1526,7 @@ void VentanaPrincipal::OnNotebookPageChanged(AUI_NAMESPACE wxAuiNotebookEvent& e
 
 }
 
-void VentanaPrincipal::OnPanelClose(AUI_NAMESPACE wxAuiManagerEvent& event)
+void VentanaPrincipal::OnPanelClose(wxAuiManagerEvent& event)
 {
 	wxWindowDisabler disabler;
 	SuperFreeze();
@@ -1572,12 +1537,12 @@ void VentanaPrincipal::OnPanelClose(AUI_NAMESPACE wxAuiManagerEvent& event)
 }
 
 
-void VentanaPrincipal::OnNotebookPageClose(AUI_NAMESPACE wxAuiNotebookEvent& event)
+void VentanaPrincipal::OnNotebookPageClose(wxAuiNotebookEvent& event)
 {
 	wxWindowDisabler disabler;
 	SuperFreeze();
-	if(CerrarVista(m_pNoteBook->GetPage(event.selection))) {
-		GNC::GCS::ControladorVistas::Instance()->Destruir(m_pNoteBook->GetPage(event.selection));
+	if(CerrarVista(m_pNoteBook->GetPage(event.GetSelection()))) {
+		GNC::GCS::ControladorVistas::Instance()->Destruir(m_pNoteBook->GetPage(event.GetSelection()));
 		if (m_pNoteBook->GetPageCount() == 1) { // Se han eliminado todas las paginas
 			//se muestra el mosaico
 			ShowStartUp(true);
@@ -1661,13 +1626,12 @@ bool VentanaPrincipal::CerrarVista(GNC::GCS::IVista* pVista)
 				SuperThaw();
 			}
 		}
-		#if defined(USE_PATCHED_LIBS)
-		AUI_NAMESPACE wxAuiNotebookEvent evt(wxEVT_COMMAND_AUINOTEBOOK_BUTTON, m_pNoteBook->GetSelection());
+		wxAuiNotebookEvent evt(wxEVT_COMMAND_AUINOTEBOOK_BUTTON, m_pNoteBook->GetSelection());
 		evt.SetInt(wxAUI_BUTTON_CLOSE);
 		evt.SetId(5380+500);
-		evt.SetEventObject(m_pNoteBook->GetActiveTabCtrl());
+		evt.SetEventObject(((wxGinkgoAuiNoteBook*)m_pNoteBook)->GetActiveTabCtrl());
 		m_pNoteBook->GetEventHandler()->ProcessEvent(evt);
-		#endif
+		
 		return ( tabCount > m_pNoteBook->GetPageCount() );
 	} else {
 		GNC::GUI::DetachedDialog* pDlg = dynamic_cast<GNC::GUI::DetachedDialog*>(pWindow->GetParent());
@@ -1723,12 +1687,12 @@ bool VentanaPrincipal::CerrarVista(wxWindow* window) {
 	return permitido;
 }
 
-void VentanaPrincipal::OnNotebookCambiarTab(AUI_NAMESPACE wxAuiNotebookEvent& event)
+void VentanaPrincipal::OnNotebookCambiarTab(wxAuiNotebookEvent& event)
 {
 	wxWindowDisabler disabler;
 	SuperFreeze();
 	if(m_pNoteBook->GetSelection()!=-1){
-		GNC::GCS::IVista* v  = GNC::GCS::ControladorVistas::Instance()->ObtenerVistaRegistrada(m_pNoteBook->GetPage(event.selection));
+		GNC::GCS::IVista* v  = GNC::GCS::ControladorVistas::Instance()->ObtenerVistaRegistrada(m_pNoteBook->GetPage(event.GetSelection()));
 		GNC::GCS::ControladorVistas* pcv = GNC::GCS::ControladorVistas::Instance();
 		if(v!=NULL && pcv != NULL){
 			pcv->SolicitarActivarVista(v);
@@ -1738,7 +1702,7 @@ void VentanaPrincipal::OnNotebookCambiarTab(AUI_NAMESPACE wxAuiNotebookEvent& ev
 	event.Skip(true);
 }
 
-void VentanaPrincipal::OnNotebookMenuTab(AUI_NAMESPACE wxAuiNotebookEvent& )
+void VentanaPrincipal::OnNotebookMenuTab(wxAuiNotebookEvent& )
 {
 	wxMenu*  menu = new wxMenu();
 	//cerrar pestania activa
@@ -1925,12 +1889,12 @@ void VentanaPrincipal::SuperFreeze()
 			m_SuperFreezeCount = 0;
 			std::cerr << "Error: Estado de bloqueo inconsistente." << std::endl;
 		}
-		Freeze();
+		/*Freeze();
 		m_pPanelActualizacion->Freeze();
 		m_pPanelCentral->Freeze();
 		m_pNoteBook->Freeze();
 		m_pMenuBar->Freeze();
-
+		*/
 	}
 	m_SuperFreezeCount++;
 }
@@ -1946,11 +1910,11 @@ void VentanaPrincipal::SuperThaw()
 			std::cerr << "Error: Estado de bloqueo inconsistente." << std::endl;
 		}
 
-		m_pMenuBar->Thaw();
+		/*m_pMenuBar->Thaw();
 		m_pNoteBook->Thaw();
 		m_pPanelCentral->Thaw();
 		m_pPanelActualizacion->Thaw();
-		Thaw();
+		Thaw();*/
 	}
 }
 
@@ -1959,11 +1923,11 @@ void VentanaPrincipal::PauseSuperFreeze()
 	if (m_SuperFreezeCount > 0) {
 		GTRACE("SuperFreeze Paused");
 
-		m_pMenuBar->Thaw();
+		/*m_pMenuBar->Thaw();
 		m_pNoteBook->Thaw();
 		m_pPanelCentral->Thaw();
 		m_pPanelActualizacion->Thaw();
-		Thaw();
+		Thaw();*/
 	}
 }
 
@@ -1971,11 +1935,11 @@ void VentanaPrincipal::ContSuperFreeze()
 {
 	if (m_SuperFreezeCount > 0) {
 		GTRACE("SuperFreeze Resumed");
-		Freeze();
+	/*	Freeze();
 		m_pPanelCentral->Freeze();
 		m_pPanelActualizacion->Freeze();
 		m_pNoteBook->Freeze();
-		m_pMenuBar->Freeze();
+		m_pMenuBar->Freeze();*/
 	}
 }
 //endregion
@@ -2057,7 +2021,7 @@ void VentanaPrincipal::MostrarVentana()
 
 //region "Getters y Setters de elementos de la interfaz"
 
-AUI_NAMESPACE wxAuiNotebook* VentanaPrincipal::GetAUINoteBook()
+wxAuiNotebook* VentanaPrincipal::GetAUINoteBook()
 {
 	return m_pNoteBook;
 }
