@@ -89,10 +89,14 @@ namespace GNC {
 			} 
 		}
 
+		void FirstLevelPanel::OnChar(wxKeyEvent &event)
+		{
+			event.ResumePropagation(10);
+			event.Skip(true);
+		}
+
 		void FirstLevelPanel::Deploy(bool show)
 		{
-			this->GetParent()->Freeze();
-			Freeze();
 			if (show) {
 				m_deployed = !m_deployed;
 				if (m_deployed) {
@@ -109,10 +113,7 @@ namespace GNC {
 
 				m_pSizerFirstLevel->Show(m_deployed);
 				Layout();
-				GNC::GCS::ControladorEventos::Instance()->ProcesarEvento(new GNC::GUI::Events::EventoLayoutHistorial(m_pView));
 			}
-			Thaw();
-			this->GetParent()->Thaw();
 		}
 
 		wxWindow* FirstLevelPanel::GetWxWindow()
@@ -162,5 +163,10 @@ namespace GNC {
 			}
 			Deploy(true);
 		}
+
+		void FirstLevelPanel::OnEraseBackground( wxEraseEvent& event )
+		{
+			event.Skip(false);
+		}
 	};
 };
