@@ -30,11 +30,13 @@ namespace GNC {
 
 
 		protected:
+			virtual void OnChar(wxKeyEvent &event);
 			void Deploy(bool show = true);
 			virtual void OnPaint(wxPaintEvent& event);
 			virtual void OnSize(wxSizeEvent &event);
 			virtual void OnMouseWheel(wxMouseEvent &event);
 			virtual void OnCabeceraClick(wxMouseEvent &event);
+			virtual void OnEraseBackground( wxEraseEvent& event );
 
 			GNC::GUI::IPreviewNode* m_pNode;
 			bool m_deployed;
