@@ -42,14 +42,13 @@ namespace GNC {
 			wxWindow* GetWxWindow();
 
 		protected:
-			virtual void OnSize(wxSizeEvent& event);
+			virtual void OnChar(wxKeyEvent &event);
 			virtual void OnHidePreviewsClick(wxCommandEvent& event);
 			virtual void OnShowPreviewsClick(wxMouseEvent& event);
 			virtual void FoldUp(bool foldup);
 			virtual void PreProcesarEvento(GNC::GCS::Events::IEvent* evt, std::list<GNC::GCS::Events::IEvent*>& lista);
 			virtual void ProcesarEvento(GNC::GCS::Events::IEvent* evt) ;
-			void OnIdle (wxIdleEvent &WXUNUSED(event));
-
+			virtual void OnEraseBackground( wxEraseEvent& event );
 			
 			GNC::GUI::ISeleccionablePreview* m_pSelected;
 			GNC::GCS::IVista* m_pView;
