@@ -19,6 +19,7 @@
 #include <wx/ginkgostyle/ginkgostyle.h>
 #include <wx/dcbuffer.h>
 #include <wx/aui/auibar.h>
+#include <wx/wxginkgotoolbar.h>
 
 #define ID_FILE_DROP_DOWN	1781
 #define ID_SHOW_HISTORY	1782
@@ -34,15 +35,12 @@ namespace GNC {
 		typedef std::list<RSSEntry> TListOfEntries;
 		//////////////////////////////////////////////////////////////////
 		///////////////////TOOL BAR///////////////////////////////////////
-		class StartupFormToolbar:public wxAuiToolBar{
+		class StartupFormToolbar : public wxGinkgoToolBar {
 		public:
-			StartupFormToolbar(wxWindow* pParent, const wxColor& color = wxColor(255, 255, 255)): wxAuiToolBar(pParent,wxID_ANY, wxDefaultPosition, wxDefaultSize, wxAUI_TB_TEXT)
+			StartupFormToolbar(wxWindow* pParent, const wxColor& color = wxColor(255, 255, 255)): wxGinkgoToolBar(pParent,wxID_ANY, wxDefaultPosition, wxDefaultSize, wxAUI_TB_TEXT)
 			{
 				SetToolBitmapSize(wxSize(64,64));
-				AUI_NAMESPACE wxAuiDefaultToolBarArt* pToolArt= new AUI_NAMESPACE wxAuiDefaultToolBarArt();
-		#if !defined(__WXOSX__) && defined(USE_PATCHED_LIBS)
-				pToolArt->SetBaseColor(color);
-		#endif
+				wxGinkgoToolBarArt* pToolArt= new wxGinkgoToolBarArt(color);
 				SetBackgroundColour(wxColour(255,255,255));
 				SetArtProvider(pToolArt);
 				
@@ -50,7 +48,8 @@ namespace GNC {
 
 				if(GNC::GCS::IControladorPermisos::Instance()->Get("core.restrictions","acquire") && GNC::GCS::IControladorPermisos::Instance()->Get("core.pacs.limits","pacs_acquisition")) {
 					AddTool(ID_FILE_DROP_DOWN, _("Acquire"), GinkgoResourcesManager::BigIcons::GetIcoBigAcquire());
-					SetToolDropDown(ID_FILE_DROP_DOWN, true);this->Connect(ID_FILE_DROP_DOWN,wxEVT_COMMAND_AUITOOLBAR_TOOL_DROPDOWN, wxAuiToolBarEventHandler(StartupFormToolbar::OnDropDownAcquire),NULL, this );
+					ForceSetToolDropDown(ID_FILE_DROP_DOWN, true);
+					this->Connect(ID_FILE_DROP_DOWN,wxEVT_COMMAND_AUITOOLBAR_TOOL_DROPDOWN, wxAuiToolBarEventHandler(StartupFormToolbar::OnDropDownAcquire),NULL, this );
 				}
 
 				GNC::HistoryToolsController::Instance()->AppendsBigToolsInToolBar(this);
@@ -217,6 +216,10 @@ namespace GNC {
 			delete IView;
 		}
 
+		void StartUpForm::OnUpgradeLink(wxHyperlinkEvent& /*event*/) {
+			
+		}
+
 		void StartUpForm::OnEraseBackground(wxEraseEvent &event)
 		{
 			event.Skip(true);
