@@ -14,8 +14,6 @@
 #include <wx/busyinfo.h>
 #include <wx/msgdlg.h>
 #include <wx/thread.h>
-#include <wx/wxhttpengine/httpbuilder.h>
-#include <wx/wxhttpengine/httpbuilderthread.h>
 
 #include <wx/tarstrm.h>
 #include <wx/zstream.h>
