@@ -22,6 +22,9 @@
 #include <api/icontexto.h>
 #include <api/iwidgetsrenderer.h>
 #include <api/iannotator.h>
+#include <api/ivista.h>
+#include <api/toolsystem/itool.h>
+#include <api/toolsystem/itoolcontroller.h>
 
 #include <eventos/modificacionwidget.h>
 
@@ -423,6 +426,18 @@ void GNC::WidgetsManager::OnMouseEvents(GNC::GCS::Events::EventoRaton& evento)
 
 	if (evento.GetSkipped()) {
 		DefaultMouseEventProcess(evento);
+		if (evento.GetSkipped()) {
+			if (this->m_pDefaultEventListenerDelegate != NULL) {
+				this->m_pDefaultEventListenerDelegate->OnMouseEvents(evento);
+			}
+			else {
+				if (m_pView != NULL && evento.ButtonUp(GNC::GCS::Events::EventoRaton::EB_DERECHO)) {
+					wxMenu menu;
+					m_pView->GetToolController()->AppendsToolInMenu(this, &menu, GNC::GCS::ITool::TSeriesMenu);
+					evento.c->pWindow->PopupMenu(&menu, wxPoint(evento.sX, evento.sY));
+				}
+			}
+		}
 	}
 	if (m_pRendererActivo != NULL && m_pRendererActivo->EstaModificado()) {
 		Render();
