@@ -53,8 +53,8 @@ namespace GNC {
 		virtual wxWindow* CreateNewToolBar(wxWindow* pParent, GNC::GCS::ITool::TToolFamily family, bool alignLeft = true);
 		virtual wxWindow* CreateNewToolBar(wxWindow* pParent, const TIdList& toolsToInclude, bool alignLeft = true);
 		virtual void AppendsToolInMenu(wxEvtHandler* pParent, wxMenu* pMenu, GNC::GCS::ITool::TToolFamily family);
-		virtual void AppendsToolsInToolBar(wxAuiToolBar* pToolBar, GNC::GCS::ITool::TToolFamily family);
-		virtual void AppendsToolsInToolBar(wxAuiToolBar* pToolBar, const GNC::GCS::IToolController::TIdList& toolsToInclude);
+		virtual void AppendsToolsInToolBar(wxGinkgoToolBar* pToolBar, GNC::GCS::ITool::TToolFamily family);
+		virtual void AppendsToolsInToolBar(wxGinkgoToolBar* pToolBar, const GNC::GCS::IToolController::TIdList& toolsToInclude);
 
 		virtual void OnKeyAccelerator(GNC::GCS::Events::EventoTeclado& evento, wxWindow* pWindow);
 
@@ -62,6 +62,9 @@ namespace GNC {
 		virtual void DoActivateTool(long idTool, const GNC::GCS::TriggerButton& buttonmask, wxWindow* pParent);
 		virtual void AppendDropDownMenu(long idTool, wxEvtHandler* pParent, wxMenu* pMenu);
 
+		//connect key events to child tools
+		virtual void ConnectKeyEvents(wxWindow* pParent);
+
 		virtual GNC::GCS::IWidgetTool* GetLeftTool();
 		virtual GNC::GCS::IWidgetTool* GetRightTool();
 
