@@ -3,7 +3,7 @@
  *  $Id: ginkgoresourcemanager.cpp $
  *  Ginkgo CADx Project
  *
- *  Copyright 2008-12 MetaEmotion S.L. All rights reserved.
+ *  Copyright 2008-14 MetaEmotion S.L. All rights reserved.
  *  http://ginkgo-cadx.com
  *
  *  This file is licensed under LGPL v3 license.
@@ -257,6 +257,24 @@ wxBitmap GinkgoResourcesManager::History::GetIcoLocalFile() {
 	return bmp;
 }
 
+wxBitmap GinkgoResourcesManager::History::GetIcoWadoLinkedRecent() {
+	wxBitmap bmp;
+	LoadPNG(bmp, HistoryDir, wxT("ico_wado_linked_recent.png"));
+	return bmp;
+}
+
+wxBitmap GinkgoResourcesManager::History::GetIcoLocalLinkedRecent() {
+	wxBitmap bmp;
+	LoadPNG(bmp, HistoryDir, wxT("ico_local_linked_recent.png"));
+	return bmp;
+}
+
+wxBitmap GinkgoResourcesManager::History::GetIcoLocalFileRecent() {
+	wxBitmap bmp;
+	LoadPNG(bmp, HistoryDir, wxT("ico_local_file_recent.png"));
+	return bmp;
+}
+
 wxBitmap GinkgoResourcesManager::History::GetIcoWadoLinked() {
 	wxBitmap bmp;
 	LoadPNG(bmp, HistoryDir, wxT("ico_wado_linked.png"));
@@ -452,6 +470,13 @@ wxBitmap GinkgoResourcesManager::ToolIcons::GetIcoCopyToClipboard()
 	return bmp;
 }
 
+wxBitmap GinkgoResourcesManager::ToolIcons::GetIcoBrightnessContrast()
+{
+	wxBitmap bmp;
+	LoadPNG(bmp, ToolIconsDir, wxT("ico_brightness_contrast.png"));
+	return bmp;
+}
+
 // Menu Icons
 wxBitmap GinkgoResourcesManager::MenuIcons::GetIcoAbrir(){
 	wxBitmap bmp;
@@ -781,6 +806,15 @@ wxImage GinkgoResourcesManager::Cursors::GetCursorAnclaCompuesta(){
 	return img;
 }
 
+wxImage GinkgoResourcesManager::Cursors::GetRotationCursor()
+{
+	wxImage img;
+	LoadPNG(img, CursorsDir, wxT("ico_rotate_cursor.png"));
+	img.SetOption(wxIMAGE_OPTION_CUR_HOTSPOT_X, 16);
+	img.SetOption(wxIMAGE_OPTION_CUR_HOTSPOT_Y, 16);
+	return img;
+}
+
 // Progres Bar
 wxAnimation GinkgoResourcesManager::ProgressBar::GetAniLoading(){
 	wxAnimation animation;
