@@ -410,193 +410,7 @@ void GinkgoInteractorStyleImage2D::OnChar()
 	//int *size = this->View->GetRenderWindow()->GetSize();
 
 	std::string key_sym(rwi->GetKeySym());
-
-	if ((key_sym.compare("Up") == 0) || (key_sym.compare("KP_Up") == 0)) {
-
-		switch (this->View->GetInteractionStyle()) {
-			/*
-			case vtkGinkgoImageViewer::WINDOW_LEVEL_INTERACTION :
-				this->StartWindowLevel();
-				this->SetWindowStep(0.0);
-				this->SetLevelStep(4.0 / size[1]);
-				this->InvokeEvent(vtkCommand::WindowLevelEvent, this);
-				this->EndWindowLevel();
-				break;
-
-			*/
-			case vtkGinkgoImageViewer::SELECT_INTERACTION :
-				this->StartZSliceMove();
-				this->ZSliceStep = 1;
-				this->InvokeEvent(GinkgoImageCommand::ZSliceMoveEvent, this);
-				this->EndZSliceMove();
-				break;
-
-			case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
-				this->StartDolly();
-				factor = 2.0;
-				//this->Dolly(pow((double)1.1, factor));
-				this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-				this->EndDolly();
-				break;
-
-			case vtkGinkgoImageViewer::ZOOM_INTERACTION :
-				this->StartDolly();
-				factor = 2.0;
-				//this->Dolly(pow((double)1.1, factor));
-				this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-				this->EndDolly();
-				break;
-
-			default:
-				break;
-		}
-	} else if ((key_sym.compare("Right") == 0) || (key_sym.compare("KP_Right") == 0)) {
-		
-	/*	switch (this->View->GetInteractionStyle()) {
-			
-			case vtkGinkgoImageViewer::WINDOW_LEVEL_INTERACTION :
-				this->StartWindowLevel();
-				this->SetWindowStep(4.0 / size[1]);
-				this->SetLevelStep(0.0);
-				this->InvokeEvent(vtkCommand::WindowLevelEvent, this);
-				this->EndWindowLevel();
-				break;
-			
-			default:
-				break;
-		}*/
-	} else if ((key_sym.compare("Left") == 0) || (key_sym.compare("KP_Left") == 0)) {
-
-	/*	switch (this->View->GetInteractionStyle()) {
-			
-			case vtkGinkgoImageViewer::WINDOW_LEVEL_INTERACTION :
-				this->StartWindowLevel();
-				this->SetWindowStep(-4.0 / size[1]);
-				this->SetLevelStep(0.0);
-				this->InvokeEvent(vtkCommand::WindowLevelEvent, this);
-				this->EndWindowLevel();
-				break;
-			
-			default:
-				break;
-		}*/
-	} else if ((key_sym.compare("Down") == 0) || (key_sym.compare("KP_Down") == 0)) {
-
-		switch (this->View->GetInteractionStyle()) {
-			/*
-			case vtkGinkgoImageViewer::WINDOW_LEVEL_INTERACTION :
-				this->StartWindowLevel();
-				this->SetWindowStep(0.0);
-				this->SetLevelStep(-4.0 / size[1]);
-				this->InvokeEvent(vtkCommand::WindowLevelEvent, this);
-				this->EndWindowLevel();
-				break;
-			*/
-			case vtkGinkgoImageViewer::SELECT_INTERACTION :
-				this->StartZSliceMove();
-				this->ZSliceStep = -1;
-				this->InvokeEvent(GinkgoImageCommand::ZSliceMoveEvent, this);
-				this->EndZSliceMove();
-				break;
-
-			case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
-				this->StartDolly();
-				factor = -2.0;
-				//this->Dolly(pow((double)1.1, factor));
-				this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-				this->EndDolly();
-				break;
-			/*
-			case vtkGinkgoImageViewer::ZOOM_INTERACTION :
-				this->StartDolly();
-				factor = -2.0;
-				//this->Dolly(pow((double)1.1, factor));
-				this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-				this->EndDolly();
-				break;
-			*/
-			default:
-				break;
-		}
-	} else if ((key_sym.compare("Page_Down") == 0) || (key_sym.compare("KP_Page_Down") == 0)) {
-		switch (this->View->GetInteractionStyle()) {
-			/*
-			case vtkGinkgoImageViewer::WINDOW_LEVEL_INTERACTION :
-				this->StartWindowLevel();
-				this->SetWindowStep(0.0);
-				this->SetLevelStep(-40.0 / size[1]);
-				this->InvokeEvent(vtkCommand::WindowLevelEvent, this);
-				this->EndWindowLevel();
-				break;
-			*/
-			case vtkGinkgoImageViewer::SELECT_INTERACTION :
-				this->StartZSliceMove();
-				this->ZSliceStep = -10;
-				this->InvokeEvent(GinkgoImageCommand::ZSliceMoveEvent, this);
-				this->EndZSliceMove();
-				break;
-
-			case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
-				this->StartDolly();
-				factor = -20.0;
-				//this->Dolly(pow((double)1.1, factor));
-				this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-				this->EndDolly();
-				break;
-
-			case vtkGinkgoImageViewer::ZOOM_INTERACTION :
-				this->StartDolly();
-				factor = -20.0;
-				//this->Dolly(pow((double)1.1, factor));
-				this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-				this->EndDolly();
-				break;
-
-			default:
-				break;
-		}
-
-	} else if ((key_sym.compare("Page_Up") == 0) || (key_sym.compare("KP_Page_Up") == 0)) {
-		switch (this->View->GetInteractionStyle()) {
-			/*
-			case vtkGinkgoImageViewer::WINDOW_LEVEL_INTERACTION :
-				this->StartWindowLevel();
-				this->SetWindowStep(0.0);
-				this->SetLevelStep(40.0 / size[1]);
-				this->InvokeEvent(vtkCommand::WindowLevelEvent, this);
-				this->EndWindowLevel();
-				break;
-			*/
-			case vtkGinkgoImageViewer::SELECT_INTERACTION :
-				this->StartZSliceMove();
-				this->ZSliceStep = 10;
-				this->InvokeEvent(GinkgoImageCommand::ZSliceMoveEvent, this);
-				this->EndZSliceMove();
-				break;
-
-			case vtkGinkgoImageViewer::ZOOM_WITH_SELECT_INTERACTION :
-				this->StartDolly();
-				factor = 20.0;
-				//this->Dolly(pow((double)1.1, factor));
-				this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-				this->EndDolly();
-				break;
-
-			case vtkGinkgoImageViewer::ZOOM_INTERACTION :
-				this->StartDolly();
-				factor = 20.0;
-				//this->Dolly(pow((double)1.1, factor));
-				this->View->SyncSetZoom(pow((double) 1.1, factor) * this->View->GetZoom());
-				this->EndDolly();
-				break;
-
-			default:
-				break;
-		}
-	}
-
-
-
+	
 	vtkAssemblyPath *path = 0;
 	vtkAbstractPropPicker *picker = 0;
 
