@@ -82,6 +82,7 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 						m_pAnguloTemp->m_Nodos[2] = evento.iP;
 						m_NodoActual = 2;
 						m_pAnguloTemp->Recalcular(evento.c->GetRenderer());
+						ConsumirEvento();
 					}
 				} else {
 					m_pAnguloTemp->m_Nodos[2] = evento.iP;
@@ -98,6 +99,7 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 						m_pAnguloTemp = NULL;
 						m_Estado = WBS_Ninguno;
 						m_NodoActual = 0;
+						ConsumirEvento();
 					}
 				}
 			} else { // Angulo de Cobb
@@ -112,6 +114,7 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 					}
 					else {
 						m_NodoActual = 2;
+						ConsumirEvento();
 					}
 				} else {
 					if ( (m_pAnguloTemp->m_Nodos[3] - m_pAnguloTemp->m_Nodos[2]).Norma2Cuadrado() < GNC::GCS::Vector::EpsilonDeReales()) {
@@ -126,11 +129,11 @@ void GNC::GCS::Widgets::WAnguloBuilder::OnMouseEvents(GNC::GCS::Events::EventoRa
 						m_pAnguloTemp = NULL;
 						m_Estado = WBS_Ninguno;
 						m_NodoActual = 0;
+						ConsumirEvento();
 					}
 				}
 			}
 			m_pManager->Modificado();
-			ConsumirEvento();
 		}
 	} else if (evento.ButtonDown(m_ButtonMask)) {
 		if (m_Estado == WBS_Ninguno) {
@@ -260,7 +263,7 @@ GNC::GCS::Widgets::WAngulo::WAngulo(IWidgetsManager* pManager, long vid, wxXmlNo
 		std::cerr<< "Ha ocurrido un error al desserializar el widget regla"<<std::endl;
 	}
 
-	if(nodo->GetPropVal(wxT("mode"),wxT("normal")) == wxT("normal")){
+	if(nodo->GetAttribute(wxT("mode"),wxT("normal")) == wxT("normal")){
 		m_Modo = MA_Normal;
 	} else {
 		m_Modo = MA_Cobb;
@@ -293,9 +296,9 @@ wxXmlNode* GNC::GCS::Widgets::WAngulo::Serializar(const std::string& nombreMedic
 {
 	wxXmlNode* resultado = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("angle_widget"));
 	if(m_Modo == MA_Normal){
-		resultado->AddProperty(wxT("mode"),wxT("normal"));
+		resultado->AddAttribute(wxT("mode"),wxT("normal"));
 	} else {
-		resultado->AddProperty(wxT("mode"),wxT("cobb"));
+		resultado->AddAttribute(wxT("mode"),wxT("cobb"));
 	}
 	//almacenamos los dos nodos
 	wxXmlNode* nodo = m_Nodos[0].Serializar();
