@@ -50,6 +50,8 @@ namespace GNC {
 				virtual GNC::GCS::Widgets::TipoCursor GetCursor();
 
 			protected:
+				TVector          m_Start;
+				bool             m_Changed;
 				Estado           m_Estado;
 				ModoAngulo       m_Modo;
 				int              m_NodoActual;
