@@ -224,7 +224,7 @@ GNC::GCS::Widgets::WElipse::WElipse(IWidgetsManager* pManager, long vid, long gi
 		} else if(child->GetName() == wxT("radioMenor")){
 			m_NodoRadioMenor = GNC::GCS::Nodo::Deserializar(child);
 		} else if(child->GetName() == wxT("rotacion")){
-			wxString strTmp = child->GetPropVal(wxT("valor"),wxT("0.0"));
+			wxString strTmp = child->GetAttribute(wxT("valor"),wxT("0.0"));
 			double doubleTmp;
 			strTmp.ToDouble(&doubleTmp);
 			m_Angulo = (float) doubleTmp;
@@ -249,8 +249,8 @@ wxXmlNode* GNC::GCS::Widgets::WElipse::Serializar(const std::string& nombreMedic
 	wxXmlNode* resultado = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("elipse_widget"));
 	//almacenamos los dos nodos
 	wxXmlNode* nodo = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("centro"));
-	nodo->AddProperty(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),m_Centro.x)));
-	nodo->AddProperty(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),m_Centro.y)));
+	nodo->AddAttribute(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),m_Centro.x)));
+	nodo->AddAttribute(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),m_Centro.y)));
 	resultado->AddChild(nodo);
 
 	nodo = m_NodoRadioMayor.Serializar();
@@ -262,7 +262,7 @@ wxXmlNode* GNC::GCS::Widgets::WElipse::Serializar(const std::string& nombreMedic
 	resultado->AddChild(nodo);
 
 	nodo = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("rotacion"));
-	nodo->AddProperty(new wxXmlProperty(wxT("valor"),wxString::Format(wxT("%f"),m_Angulo)));
+	nodo->AddAttribute(new wxXmlProperty(wxT("valor"),wxString::Format(wxT("%f"),m_Angulo)));
 	resultado->AddChild(nodo);
 
 	//metadatos
