@@ -161,32 +161,32 @@ GNC::GCS::Widgets::WCajaTexto::WCajaTexto(IWidgetsManager* pManager, long vid, w
 {
 	m_AnchoMaximo = 150.0f;
 
-	wxString strTmp = nodo->GetPropVal(wxT("x"),wxT("0.0"));
+	wxString strTmp = nodo->GetAttribute(wxT("x"),wxT("0.0"));
 	double doubleTmp;
 	strTmp.ToDouble(&doubleTmp);
 	m_Posicion.x = (float) doubleTmp;
 
-	strTmp = nodo->GetPropVal(wxT("y"),wxT("0.0"));
+	strTmp = nodo->GetAttribute(wxT("y"),wxT("0.0"));
 	strTmp.ToDouble(&doubleTmp);
 	m_Posicion.y = (float) doubleTmp;
 
-	strTmp = nodo->GetPropVal(wxT("r"),wxT("1.0"));
+	strTmp = nodo->GetAttribute(wxT("r"),wxT("1.0"));
 	strTmp.ToDouble(&doubleTmp);
 	m_Color.SetRF((float) doubleTmp);
 
-	strTmp = nodo->GetPropVal(wxT("g"),wxT("1.0"));
+	strTmp = nodo->GetAttribute(wxT("g"),wxT("1.0"));
 	strTmp.ToDouble(&doubleTmp);
 	m_Color.SetGF((float) doubleTmp);
 
-	strTmp = nodo->GetPropVal(wxT("b"),wxT("1.0"));
+	strTmp = nodo->GetAttribute(wxT("b"),wxT("1.0"));
 	strTmp.ToDouble(&doubleTmp);
 	m_Color.SetBF((float) doubleTmp);
 
-	strTmp = nodo->GetPropVal(wxT("a"),wxT("1.0"));
+	strTmp = nodo->GetAttribute(wxT("a"),wxT("1.0"));
 	strTmp.ToDouble(&doubleTmp);
 	m_Color.SetAF((float) doubleTmp);
 
-	m_Texto = std::string(nodo->GetPropVal(wxT("text"),wxT("")).ToUTF8());
+	m_Texto = std::string(nodo->GetAttribute(wxT("text"),wxT("")).ToUTF8());
 
 	m_Vacio = false;
 	m_MouseDown = false;
@@ -198,13 +198,13 @@ wxXmlNode* GNC::GCS::Widgets::WCajaTexto::Serializar(const std::string& nombreMe
 {
 	wxXmlNode* resultado = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("text_widget"));
 	//almacenamos los dos nodos
-	resultado->AddProperty(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),m_Posicion.x)));
-	resultado->AddProperty(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),m_Posicion.y)));
-	resultado->AddProperty(new wxXmlProperty(wxT("r"),wxString::Format(wxT("%f"),m_Color.RF())));
-	resultado->AddProperty(new wxXmlProperty(wxT("g"),wxString::Format(wxT("%f"),m_Color.GF())));
-	resultado->AddProperty(new wxXmlProperty(wxT("b"),wxString::Format(wxT("%f"),m_Color.BF())));
-	resultado->AddProperty(new wxXmlProperty(wxT("a"),wxString::Format(wxT("%f"),m_Color.AF())));
-	resultado->AddProperty(new wxXmlProperty(wxT("text"),wxString::FromUTF8(m_Texto.c_str())));
+	resultado->AddAttribute(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),m_Posicion.x)));
+	resultado->AddAttribute(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),m_Posicion.y)));
+	resultado->AddAttribute(new wxXmlProperty(wxT("r"),wxString::Format(wxT("%f"),m_Color.RF())));
+	resultado->AddAttribute(new wxXmlProperty(wxT("g"),wxString::Format(wxT("%f"),m_Color.GF())));
+	resultado->AddAttribute(new wxXmlProperty(wxT("b"),wxString::Format(wxT("%f"),m_Color.BF())));
+	resultado->AddAttribute(new wxXmlProperty(wxT("a"),wxString::Format(wxT("%f"),m_Color.AF())));
+	resultado->AddAttribute(new wxXmlProperty(wxT("text"),wxString::FromUTF8(m_Texto.c_str())));
 	//metadatos
 	SerializarMetadatos(resultado,nombreMedico);
 	return resultado;
