@@ -211,7 +211,7 @@ GNC::GCS::Widgets::WPoligono::WPoligono(IWidgetsManager* pManager, long vid, wxX
 		std::cerr<< "Ha ocurrido un error al desserializar el widget poligono"<<std::endl;
 	}
 
-	if(nodo->GetPropVal(wxT("mode"),wxT("normal")) == wxT("lazo")){
+	if(nodo->GetAttribute(wxT("mode"),wxT("normal")) == wxT("lazo")){
 		m_Modo = MP_Lazo;
 	} else {
 		m_Modo = MP_Normal;
@@ -236,16 +236,16 @@ wxXmlNode* GNC::GCS::Widgets::WPoligono::Serializar(const std::string& nombreMed
 {
 	wxXmlNode* resultado = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("poligono_widget"));
 	if(m_Modo == MP_Lazo){
-		resultado->AddProperty(wxT("mode"),wxT("lazo"));
+		resultado->AddAttribute(wxT("mode"),wxT("lazo"));
 	} else {
-		resultado->AddProperty(wxT("mode"),wxT("normal"));
+		resultado->AddAttribute(wxT("mode"),wxT("normal"));
 	}
 
 	int i=0;
 	for (VerticesPoligono::iterator it = m_Vertices.begin(); it != m_Vertices.end(); ++it) {
-		wxXmlNode* nodo = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxString::Format(wxT("nodo%d"),i));
-		nodo->AddProperty(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),(*it).x)));
-		nodo->AddProperty(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),(*it).y)));
+		wxXmlNode* nodo = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxString::Format(wxT("nodo%d"), (int) i));
+		nodo->AddAttribute(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),(*it).x)));
+		nodo->AddAttribute(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),(*it).y)));
 		resultado->AddChild(nodo);
 		i++;
 	}
