@@ -105,12 +105,12 @@ GNC::GCS::Widgets::WPunto::WPunto(IWidgetsManager* pManager, long vid, long gid,
 		std::cerr<< "Ha ocurrido un error al desserializar el widget puntos"<<std::endl;
 	}
 
-	wxString strTmp = nodo->GetPropVal(wxT("x"),wxT("0.0"));
+	wxString strTmp = nodo->GetAttribute(wxT("x"),wxT("0.0"));
 	double doubleTmp;
 	strTmp.ToDouble(&doubleTmp);
 	m_Nodo.x = (float) doubleTmp;
 
-	strTmp = nodo->GetPropVal(wxT("y"),wxT("0.0"));
+	strTmp = nodo->GetAttribute(wxT("y"),wxT("0.0"));
 	strTmp.ToDouble(&doubleTmp);
 	m_Nodo.y = (float) doubleTmp;
 
@@ -123,8 +123,8 @@ GNC::GCS::Widgets::WPunto::WPunto(IWidgetsManager* pManager, long vid, long gid,
 wxXmlNode* GNC::GCS::Widgets::WPunto::Serializar(const std::string& nombreMedico) {
 	wxXmlNode* resultado = new wxXmlNode(NULL,wxXML_ELEMENT_NODE,wxT("punto_widget"));
 	//almacenamos los dos nodos
-	resultado->AddProperty(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),m_Nodo.x)));
-	resultado->AddProperty(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),m_Nodo.y)));
+	resultado->AddAttribute(new wxXmlProperty(wxT("x"),wxString::Format(wxT("%f"),m_Nodo.x)));
+	resultado->AddAttribute(new wxXmlProperty(wxT("y"),wxString::Format(wxT("%f"),m_Nodo.y)));
 	//serializar Metadatos
 	SerializarMetadatos(resultado,nombreMedico);
 	return resultado;
