@@ -251,7 +251,8 @@ void wxThumbnailCtrl::Clear()
 static bool wxGetIntegerFromFilename(const wxString& fname, int& n)
 {
     wxString filename = fname;
-    wxStripExtension(filename);
+
+    wxFileName::StripExtension(filename);
     wxString strNum;
 
     size_t len = filename.Len();
@@ -359,13 +360,13 @@ int wxThumbnailCtrlCmpFunc(wxThumbnailItem** item1, wxThumbnailItem** item2)
         wxString filename2, path2, ext2;
         if (sortMode == wxTHUMBNAIL_SORT_TYPE_UP)
         {
-            wxSplitPath((*item1)->GetFilename(), & filename1, & path1, & ext1);
-            wxSplitPath((*item2)->GetFilename(), & filename2, & path2, & ext2);
+            wxFileName::SplitPath((*item1)->GetFilename(), & filename1, & path1, & ext1);
+            wxFileName::SplitPath((*item2)->GetFilename(), & filename2, & path2, & ext2);
         }
         else
         {
-            wxSplitPath((*item2)->GetFilename(), & filename1, & path1, & ext1);
-            wxSplitPath((*item1)->GetFilename(), & filename2, & path2, & ext2);
+            wxFileName::SplitPath((*item2)->GetFilename(), & filename1, & path1, & ext1);
+            wxFileName::SplitPath((*item1)->GetFilename(), & filename2, & path2, & ext2);
         }
         return ext1.CmpNoCase(ext2);
     }
