@@ -296,7 +296,6 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::OpenView(int mod
 	{
 		{//comienza la deshabilitacion
 			pVentanaPadre = pCtrlVistas->GetRootWindow();
-			pCtrlVistas->Freeze();
 			try{
 				if (hangingProtocol.IsValid() && !hangingProtocol->getLayouts().empty())  {
 					for (GNC::GCS::HangingProtocol::TListOfLayouts::const_iterator it = hangingProtocol->getLayouts().begin(); it != hangingProtocol->getLayouts().end(); ++it)
@@ -312,7 +311,6 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::OpenView(int mod
 				if (pVista != NULL) {
 					pCtrlVistas->Destruir(pVista);
 				}
-				pCtrlVistas->Thaw();
 				wxString mensaje = wxString::FromUTF8(ex.GetCause().c_str());
 				wxMessageDialog dialogo( m_pEntorno->GetVentanaRaiz(), mensaje, _("Error opening study"),  wxOK | wxICON_INFORMATION);
 				dialogo.ShowModal();
@@ -322,12 +320,10 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::OpenView(int mod
 				if (pVista != NULL) {
 					pCtrlVistas->Destruir(pVista);
 				}
-				pCtrlVistas->Thaw();
 				wxMessageDialog dialogo( m_pEntorno->GetVentanaRaiz(), _("Error opening study"), _("Error opening study"),  wxOK | wxICON_INFORMATION);
 				dialogo.ShowModal();
 				return NULL;
 			}
-			pCtrlVistas->Thaw();
 		}//fin deshabilitacion
 	}
 	else if (m_ListaModos[modo]->GetDescripcion() == _Std("Waveform viewer") && !pkSeries.empty()) 
@@ -336,7 +332,6 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::OpenView(int mod
 		{
 			{//comienza la deshabilitacion
 				pVentanaPadre = pCtrlVistas->GetRootWindow();
-				pCtrlVistas->Freeze();
 				try{	
 					LOG_STAT(ANON_STAT_VIEW_ECG)
 					wxWindowDisabler disabler;
@@ -352,7 +347,6 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::OpenView(int mod
 					if (pVista != NULL) {
 						pCtrlVistas->Destruir(pVista);
 					}
-					pCtrlVistas->Thaw();
 					wxString mensaje = wxString::FromUTF8(ex.GetCause().c_str());
 					wxMessageDialog dialogo( m_pEntorno->GetVentanaRaiz(), mensaje, _("Error opening study"),  wxOK | wxICON_INFORMATION);
 					dialogo.ShowModal();
@@ -362,18 +356,14 @@ GNC::GCS::IVista* GNKVisualizator::ControladorAtencionPrimaria::OpenView(int mod
 					if (pVista != NULL) {
 						pCtrlVistas->Destruir(pVista);
 					}
-					pCtrlVistas->Thaw();
 					wxMessageDialog dialogo( m_pEntorno->GetVentanaRaiz(), _("Error opening study"), _("Error opening study"),  wxOK | wxICON_INFORMATION);
 					dialogo.ShowModal();
 					return NULL;
 				}
-				pCtrlVistas->Thaw();
 			}//fin deshabilitacion
 
 			if (pVista == NULL ) {
-				pCtrlVistas->Freeze();
 				pCtrlVistas->Destruir(pVista);
-				pCtrlVistas->Thaw();
 				return NULL;
 			}
 			else {
