@@ -151,7 +151,7 @@ int calcNrOfValues(const TMapVectorStrings& vals)
 	return nr;
 }
 
-TMapVectorStrings GetValues(GIL::DICOM::DicomDataset* sequence, TVectorPairStrings& items, TVectorPairStrings& units, std::list<int>& rwc, bool special)
+TMapVectorStrings GetValues(GIL::DICOM::DicomDataset* sequence, TVectorPairStrings& items, TVectorPairStrings& units, std::list<int>& /*rwc*/, bool special)
 {
 	TMapVectorStrings result;
 
