@@ -75,22 +75,21 @@
 #include <api/toolsystem/itool.h>
 #include <visualizator/wxvtk/previewpanelvisualizator.h>
 
-#define ID_BOTON_PLAY_STOP 0
+#include <wx/wxginkgotoolbar.h>
+
 #define ID_BOTON_VER 1
 #define ID_BOTON_LAYOUT 2
 #define ID_BOTON_SINCRONIZAR 3
 #define ID_BOTON_DESENCAJAR 4
 
 //esta clase sirve para las barras de herramientas de abajo
-class BarraHerramientasBotones:public wxAuiToolBar{
+class BarraHerramientasBotones : public wxGinkgoToolBar{
 public:
-	BarraHerramientasBotones(wxWindow* pParent, const wxColor& color = wxColor(0x40, 0x40, 0x40)): wxAuiToolBar(pParent,wxID_ANY, wxDefaultPosition, wxDefaultSize, wxAUI_TB_DEFAULT_STYLE)
+	BarraHerramientasBotones(wxWindow* pParent, const wxColor& color = wxColor(0x40, 0x40, 0x40)): wxGinkgoToolBar(pParent,wxID_ANY, wxDefaultPosition, wxDefaultSize, wxAUI_TB_DEFAULT_STYLE)
 	{
 		SetToolBitmapSize(wxSize(16,16));
-		AUI_NAMESPACE wxAuiDefaultToolBarArt* pToolArt= new AUI_NAMESPACE wxAuiDefaultToolBarArt();
-#if defined(USE_PATCHED_LIBS) && !defined(__WXOSX__)
-		pToolArt->SetBaseColor(color);
-#endif
+		wxGinkgoToolBarArt* pToolArt= new wxGinkgoToolBarArt();
+		pToolArt->SetCustomBaseColor(color);
 		SetArtProvider(pToolArt);
 	}
 
@@ -99,57 +98,6 @@ public:
 	}
 };
 
-//esta clase sirve para no tener que definir identificadores en las opciones de periodo en el cine
-class ItemFrameRate: protected wxEvtHandler, public wxMenuItem {
-public:
-	ItemFrameRate(wxMenu *parentMenu,const wxString& text,GVistaCompleja* pVista,int periodo):wxMenuItem(parentMenu,wxID_ANY,text,wxEmptyString,wxITEM_CHECK)
-	{
-		m_pVista = pVista;
-		m_periodo = periodo;
-		int id = wxMenuItem::GetId();
-		#ifdef __WXMSW__
-		parentMenu->GetParent()->Connect(id,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ItemFrameRate::OnMenuClick),NULL,this);
-		#else
-		parentMenu->Connect(id,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ItemFrameRate::OnMenuClick),NULL,this);
-		#endif
-	}
-	~ItemFrameRate(){
-		m_pVista =NULL;
-		int id = wxMenuItem::GetId();
-		#ifdef __WXMSW__
-		GetMenu()->GetParent()->Disconnect(id,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ItemFrameRate::OnMenuClick ),NULL,this);
-		#else
-		GetMenu()->Disconnect(id,wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( ItemFrameRate::OnMenuClick ),NULL,this);
-		#endif
-	}
-
-	void OnMenuClick(wxCommandEvent &event) {
-		m_pVista->SetPeriodo(m_periodo);
-		event.Skip(false);
-	}
-
-
-	GVistaCompleja* m_pVista;
-	int m_periodo;
-};
-
-///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-class TimerPlay:public wxTimer
-{
-public:
-	TimerPlay(GVistaCompleja *pVista){
-		m_pVista=pVista;
-	}
-
-	~TimerPlay() {}
-
-	virtual void Notify(){
-		m_pVista->OnTimer();
-	}
-
-	GVistaCompleja *m_pVista;
-};
-
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 
 class GVistaComplejaOverlaysDelegate: public GNKVisualizator::IOverlaysContract
@@ -192,7 +140,6 @@ public:
 			//layout invalido aunque podría ser valido...
 			filas = (int)std::ceil((double)maxSlices/columnas);
 		}
-		GView->Freeze();
 
 		int filasActuales = GView->m_pSizerSeries->GetRows();
 		int columnasActuales = GView->m_pSizerSeries->GetCols();
@@ -241,7 +188,6 @@ public:
 		GView->Layout();
 		//nos quedamos en la posicion
 		GView->GoToSlice(GView->m_posicion,false,false,false);
-		GView->Thaw();
 		if ( (filas > 1 || columnas > 1) && incrementado) { // condición para evitar doble render. Ya se comprueba por otro lado en la creación (con 1 vista).
 			bool noerror = true;
 			for(GVistaCompleja::TListaGVistasSimples::iterator it = GView->m_VistasSimples.begin(); noerror && it !=GView-> m_VistasSimples.end(); ++it) {
@@ -334,7 +280,7 @@ public:
 		int tsize = GView->IVista->VisualizatorStudy->GetTSizeActive();
 
 		if (tsize == 1) {
-			return GView->IVista->VisualizatorStudy->GetSliceNumber();
+			return GView->m_pSliderSlice->GetValue();
 		}
 		else {
 			GVistaCompleja::TListaGVistasSimples::iterator it = GView->m_VistasSimples.begin();
@@ -557,14 +503,9 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 {
 	IVista->GetVisualizatorStudy()->Window = this;
 	m_hasBeenRendered = false;
-	m_ReproducirBucle = false;
-	m_PeriodoMs = 500;
 	m_posicion = m_pSliderSlice->GetValue();
 
 	// Setup del manejador de widgets */
-	
-
-	m_playTimer = new TimerPlay(this);
 
 	//toolbar
 	GNC::GCS::IToolController* pToolBar = IVista->GetToolController();
@@ -576,11 +517,14 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 	pToolBar->AddTool(HCore_Angulo, (GNC::GCS::ISliderContract*) Delegate);
 	pToolBar->AddTool(HCore_Rule, (GNC::GCS::IRuleContract*) Delegate);
 	pToolBar->AddTool(HCore_Nota, (GNC::GCS::ISliderContract*) Delegate);
+	pToolBar->AddTool(HCore_Video, (GNC::GCS::ISliderContract*) Delegate);
 	pToolBar->AddTool(HCore_Marcado, (GNC::GCS::ISliderContract*) Delegate);
 	pToolBar->AddTool(HCore_WindowLevel, (GNC::GCS::IWindowLevelContract*) Delegate);
 	//view menu...
 	pToolBar->AddTool(HCore_CornerAnnotations, (GNC::GCS::ISliderContract*) Delegate);
+	#if !defined(__WXGTK__)
 	pToolBar->AddTool(HCore_DetachWindow, (GNC::GCS::IViewContract*) IVista);
+	#endif
 	pToolBar->AddTool(HCore_MetricGrid, (GNC::GCS::ISliderContract*) Delegate);
 	pToolBar->AddTool(HCore_PixelsBluring, PixelsBluringDelegate);
 	pToolBar->AddTool(HCore_Reset, (GNC::GCS::ISliderContract*) Delegate);
@@ -589,13 +533,13 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 
 	pToolBar->AddTool(HCore_SecondaryCapture, (GNC::GCS::ISliderContract*)Delegate);
 	pToolBar->AddTool(HCore_CopyImageToClipboard, (GNC::GCS::ISliderContract*)Delegate);
+	pToolBar->AddTool(HCore_SimplePrint, (GNC::GCS::ISliderContract*)Delegate);
 	//tools
 	pToolBar->AddTool(HCore_ShowDicomTags, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_ShowHistory, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_ColorMap, (GNC::GCS::ISliderContract*) Delegate);
 	pToolBar->AddTool(HGNKVisualizator_Overlays, OverlaysDelegate);
 	pToolBar->AddTool(HCore_ImageExport, ExportDelegate);
-	pToolBar->AddTool(HCore_ImagePrint, ExportDelegate);
 	pToolBar->AddTool(HCore_Deshacer, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_PACSUpload, (GNC::GCS::IViewContract*) IVista);
 	pToolBar->AddTool(HCore_DicomizeFromView, (GNC::GCS::IViewContract*) IVista);
@@ -614,6 +558,9 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 		m_pSizerTools->Add(pwxToolBar, 1, wxEXPAND);
 	}
 
+	//connect key events..
+	pToolBar->ConnectKeyEvents(this);
+
 	//preview series and drag & drop	
 	m_pSizerView->Insert(0, m_pPanelPreview, 0, wxEXPAND);
 	SetDropTarget(new GNKVisualizator::GUI::wxDropTargetPreviewPanelVisualizator(this));		
@@ -628,33 +575,24 @@ GVistaCompleja::GVistaCompleja(GNKVisualizator::Vista2D* pIVista) : VistaComplej
 
 	{
 		GNC::GCS::IToolController::TIdList toolsLeft;
+		#if !defined(__WXGTK__)
 		toolsLeft.push_back(HCore_DetachWindow);
+		#endif
 		toolsLeft.push_back(HCore_WindowLayout);
+		toolsLeft.push_back(HCore_Video);
 		wxWindow* toolBarLeft = pToolBar->CreateNewToolBar(m_pPanelManipulacion, toolsLeft);
 		m_pSizerIzquierda->Add(toolBarLeft,0, wxALIGN_CENTER_VERTICAL|wxEXPAND,0);		
 	}
-
-	m_pBarraCine = new BarraHerramientasBotones(m_pPanelManipulacion);
-	m_pBarraCine->AddTool(ID_BOTON_PLAY_STOP,_("Play"),GinkgoResourcesManager::CineBar::GetIcoPlay(),_("Play"));
-	m_pBarraCine->Connect(ID_BOTON_PLAY_STOP,wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler( GVistaCompleja::OnPlayStopClick),NULL,this);
-	m_pBarraCine->SetToolDropDown(ID_BOTON_PLAY_STOP, true);
-	m_pBarraCine->Connect(ID_BOTON_PLAY_STOP,wxEVT_COMMAND_AUITOOLBAR_TOOL_DROPDOWN, wxAuiToolBarEventHandler( GVistaCompleja::OnMenuCineClick),NULL,this);
-
-	m_pBarraCine->Realize();
-	m_pSizerIzquierda->Add(m_pBarraCine,0, wxALIGN_CENTER_VERTICAL|wxEXPAND,0);
-
 	//se añaden los de sincronizar/dessincronizar
 	m_pBarraDerecha = new BarraHerramientasBotones(m_pPanelManipulacion);
 	m_pBarraDerecha->AddTool(ID_BOTON_SINCRONIZAR,_("Synchronize/Des synchronize"),GNKVisualizator::ResourcesManager::SynchronizationBar::GetIcoDessincronizar(),_("Synchronize/Des synchronize"),wxITEM_CHECK);
 	m_pBarraDerecha->Connect(ID_BOTON_SINCRONIZAR,wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler( GVistaCompleja::OnSincronizarClick),NULL,this);
-	m_pBarraDerecha->ToggleTool(ID_BOTON_SINCRONIZAR,false);
+	m_pBarraDerecha->ForceToggleTool(ID_BOTON_SINCRONIZAR,false);
 
 	m_pBarraDerecha->Realize();
 	m_pSizerDerecho->Add(m_pBarraDerecha,0, wxALIGN_CENTER_VERTICAL|wxEXPAND,0);
 
 	//Connect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GVistaCompleja::OnFocus),NULL,this);
-	Connect(wxEVT_KEY_DOWN,wxKeyEventHandler(GVistaCompleja::OnKeyDown),NULL,this);
-	Connect(wxEVT_CHAR,wxKeyEventHandler(GVistaCompleja::OnKeyDown),NULL,this);
 	Connect(wxEVT_MOUSEWHEEL,wxMouseEventHandler(GVistaCompleja::OnMouseWheel),NULL,this);
 
 	GNC::GCS::Events::EventoModificacionImagen ev2(IVista);
@@ -695,21 +633,12 @@ GVistaCompleja::~GVistaCompleja()
 	}
 
 	//Disconnect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GVistaCompleja::OnFocus),NULL,this);
-	this->Disconnect(wxEVT_KEY_DOWN,wxKeyEventHandler(GVistaCompleja::OnKeyDown),NULL,this);
 	this->Disconnect(wxEVT_MOUSEWHEEL,wxMouseEventHandler(GVistaCompleja::OnMouseWheel),NULL,this);
 
 	if(m_ListaSincronizacion.size() >0){
-		//si esta reproduciendose se para
-		Stop();
-		//
 		DesSincronizar();
 	}
 
-	if(m_playTimer!= NULL) {
-		delete m_playTimer;
-		m_playTimer = NULL;
-	}
-
 	m_pManager->EliminarTodosLosWidgets(false);
 
 	m_VistasSimples.clear();
@@ -850,6 +779,7 @@ void GVistaCompleja::DetenerPipeline()
 void GVistaCompleja::OnCargaFinalizada()
 {
 	m_pPanelPreview->LoadModel();
+	Layout();
 	m_pManager->OcultarTodosLosWidgets(true, 666);
 	m_pManager->DisableAnimation();
 	m_pManager->Render();
@@ -922,78 +852,6 @@ void GVistaCompleja::OnMenuVerClick(wxCommandEvent& )
 	m_pBarraIzquierda->SetToolSticky(ID_BOTON_VER, false);
 }
 
-
-void GVistaCompleja::OnMenuCineClick(wxAuiToolBarEvent& evt)
-{
-	if (evt.IsDropDownClicked())
-	{
-		wxAuiToolBar* tb = static_cast<wxAuiToolBar*>(evt.GetEventObject());
-		tb->SetToolSticky(evt.GetId(), true);
-
-		IVista->OnFocus();
-		//se crea el menu
-		wxMenu menuVer;
-		wxMenu* pMenuFrameRate = new wxMenu();
-		menuVer.AppendSubMenu(pMenuFrameRate,_("Speed"));
-		//importante si se añade un titulo añadir un periodo!!
-		wxString titulos[8] = {wxT("20 fps"), wxT("8 fps"),wxT("4 fps"),wxT("2 fps"),wxT("1 fps"),wxT("0.5 fps"),wxT("0.2 fps"),wxT("0.1 fps")};
-		int periodos[8] = {50,125,250,500,1000,2000,5000,10000};
-		for(int i=0; i < 8; i++)
-		{
-			wxMenuItem* pItem = new ItemFrameRate(pMenuFrameRate,titulos[i],this,periodos[i]);
-			pMenuFrameRate->Append(pItem);
-			if(periodos[i] == m_PeriodoMs) {
-				pItem->Check(true);
-			}
-		}
-
-		wxMenuItem* pItem = new wxMenuItem(&menuVer,wxID_ANY,_("Loop"),_("Repeat on end"),wxITEM_CHECK);
-		#ifdef __WXMSW__
-		pItem->SetBitmaps(GinkgoResourcesManager::CineBar::GetIcoBucle(),GinkgoResourcesManager::CineBar::GetIcoNoBucle());
-		//#else
-		//pItem->SetBitmap(GinkgoResourcesManager::CineBar::GetIcoBucle());
-		#endif
-		//este apend suelta por consola: 'InsertMenuItem()' failed with error 0x00000057, es un buf arreglado pero no afecta negativamente,
-		// es xq solo tiene un bitmap mas info:
-		//http://trac.wxwidgets.org/ticket/9878
-		menuVer.Append(pItem);
-		//
-		menuVer.Check(pItem->GetId(),m_ReproducirBucle);
-		menuVer.Connect(pItem->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( GVistaCompleja::OnBucleClick ),NULL,this);
-
-		if(!m_playTimer->IsRunning()){
-			pItem = new wxMenuItem(&menuVer,wxID_ANY,_("Play"),_("Start playback"));
-			#ifdef __WXMSW__
-			pItem->SetBitmaps(GinkgoResourcesManager::CineBar::GetIcoPlay());
-			#else
-			pItem->SetBitmap(GinkgoResourcesManager::CineBar::GetIcoPlay());
-			#endif
-			menuVer.Append(pItem);
-			menuVer.Connect(pItem->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( GVistaCompleja::OnPlayStopClick ),NULL,this);
-		} else {
-			pItem = new wxMenuItem(&menuVer,wxID_ANY,_("Stop"),_("End playback"));
-			#ifdef __WXMSW__
-			pItem->SetBitmaps(GinkgoResourcesManager::CineBar::GetIcoPause());
-			#else
-			pItem->SetBitmap(GinkgoResourcesManager::CineBar::GetIcoPause());
-			#endif
-			menuVer.Append(pItem);
-			menuVer.Connect(pItem->GetId(),wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( GVistaCompleja::OnPlayStopClick ),NULL,this);
-		}
-
-		wxRect rect = tb->GetToolRect(evt.GetId());
-		wxPoint pt = tb->ClientToScreen(rect.GetBottomLeft());
-		pt = ScreenToClient(pt);
-
-
-		PopupMenu(&menuVer, pt);
-
-		// make sure the button is "un-stuck"
-		tb->SetToolSticky(evt.GetId(), false);
-	}
-}
-
-
 void GVistaCompleja::ActualizarMaxMinSlider()
 {
 	//depende de m_MinSlice y m_MaxSlice;
@@ -1003,12 +861,6 @@ void GVistaCompleja::ActualizarMaxMinSlider()
 	if (minSlider < maxSlider) {
 		m_pSliderSlice->SetRange(minSlider, maxSlider);
 		m_pSliderSlice->Enable(true);
-		if( !m_pBarraCine->IsShown() ) {
-			m_pBarraCine->SetToolBitmap(ID_BOTON_PLAY_STOP, GinkgoResourcesManager::CineBar::GetIcoPlay());
-			m_pBarraCine->SetToolShortHelp(ID_BOTON_PLAY_STOP, _("Play"));
-			m_pBarraCine->Enable(true);
-			m_pBarraCine->Show(true);
-		}
 		m_pSliderSlice->Show(true);
 		m_pBarraDerecha->Show(true);
 		m_pBarraDerecha->Refresh();
@@ -1018,25 +870,11 @@ void GVistaCompleja::ActualizarMaxMinSlider()
 		{
 			Sincronizar(false);
 		}
-		if(m_playTimer->IsRunning()) {
-			Stop();
-		}
-		m_pBarraCine->Hide();
 		m_pSliderSlice->Show(false);
 		m_pBarraDerecha->Show(false);
 	}
 }
 
-void GVistaCompleja::SetPeriodo(int milisegundos)
-{
-	if(milisegundos>0) {
-		m_PeriodoMs = milisegundos;
-		if(m_playTimer->IsRunning()){
-			m_playTimer->Stop();
-			m_playTimer->Start(m_PeriodoMs);
-		}
-	}
-}
 
 void GVistaCompleja::OnFocus(wxChildFocusEvent &)
 {
@@ -1057,25 +895,6 @@ void GVistaCompleja::OnZSliderScroll (wxScrollEvent& event) {
 	event.Skip(false);
 }
 
-void GVistaCompleja::OnKeyDown( wxKeyEvent& event )
-{
-	switch(event.GetKeyCode()){
-		case WXK_RIGHT:
-			{
-				GoToSlice(1);
-			}
-			break;
-		case WXK_LEFT:
-			{
-				GoToSlice(-1);
-			}
-			break;
-		default:
-			event.ResumePropagation(1);
-			event.Skip(true);
-	}
-}
-
 void GVistaCompleja::OnMouseWheel(wxMouseEvent& event)
 {
 	if (event.ControlDown())
@@ -1104,57 +923,6 @@ void GVistaCompleja::OnMouseWheel(wxMouseEvent& event)
 	} 
 }
 
-void GVistaCompleja::OnPlayStopClick(wxCommandEvent &){
-	if(!m_playTimer->IsRunning()) {
-		Play();
-	} else {
-		Stop();
-	}
-}
-
-void GVistaCompleja::Play()
-{
-	if(!m_ReproducirBucle && m_pSliderSlice->GetValue() == m_pSliderSlice->GetMax()){
-		GoToSlice(0,false);
-	}
-	m_playTimer->Start(m_PeriodoMs);
-	m_pBarraCine->SetToolBitmap(ID_BOTON_PLAY_STOP, GinkgoResourcesManager::CineBar::GetIcoStop());
-	m_pBarraCine->SetToolShortHelp(ID_BOTON_PLAY_STOP, _("Stop"));
-	m_pBarraCine->Refresh();
-
-	AtencionPrimaria::Events::EventoSincronizacion* evt = new AtencionPrimaria::Events::EventoSincronizacion(IVista,AtencionPrimaria::Events::EventoSincronizacion::Play);
-	GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(evt);
-}
-
-void GVistaCompleja::Stop()
-{
-	//stop
-	m_playTimer->Stop();
-	m_pBarraCine->SetToolBitmap(ID_BOTON_PLAY_STOP, GinkgoResourcesManager::CineBar::GetIcoPlay());
-	m_pBarraCine->SetToolShortHelp(ID_BOTON_PLAY_STOP, _("Play"));
-	m_pBarraCine->Refresh();
-
-	AtencionPrimaria::Events::EventoSincronizacion* evt = new AtencionPrimaria::Events::EventoSincronizacion(IVista,AtencionPrimaria::Events::EventoSincronizacion::Stop);
-	GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(evt);
-}
-
-void GVistaCompleja::OnBucleClick(wxCommandEvent &){
-	m_ReproducirBucle = !m_ReproducirBucle;
-}
-
-void GVistaCompleja::OnTimer()
-{
-	if((m_pSliderSlice->GetValue() +1 ) >m_pSliderSlice->GetMax() && m_ReproducirBucle){
-		GoToSlice(0,false);
-	} else {
-		GoToSlice(1);
-
-		if(m_pSliderSlice->GetValue()  == m_pSliderSlice->GetMax() && !m_ReproducirBucle){
-			Stop();
-		}
-	}
-}
-
 void GVistaCompleja::ActualizarImagen()
 {
 	//m_pImagenOriginal->Modified();
@@ -1220,9 +988,6 @@ void GVistaCompleja::Sincronizar(bool sincronizar)
 	//si esta toogled...
 	if(!sincronizar) {
 		//dessincronizar
-		//si esta reproduciendose se para
-		Stop();
-		//
 		DesSincronizar();
 	} else {
 		//sincronizar
@@ -1253,10 +1018,10 @@ void GVistaCompleja::Sincronizar(bool sincronizar)
 				for(DialogoSincronizacion::TipoListaVistas::iterator it = lista.begin(); it!= lista.end(); ++it){
 					(*it)->GVista->Sincronizar(lista);
 				}
-				m_pBarraDerecha->ToggleTool(ID_BOTON_SINCRONIZAR,true);
+				m_pBarraDerecha->ForceToggleTool(ID_BOTON_SINCRONIZAR,true);
 				m_pBarraDerecha->Refresh();
 			} else {
-				m_pBarraDerecha->ToggleTool(ID_BOTON_SINCRONIZAR,false);
+				m_pBarraDerecha->ForceToggleTool(ID_BOTON_SINCRONIZAR,false);
 				m_pBarraDerecha->Refresh();
 			}
 		}
@@ -1265,8 +1030,6 @@ void GVistaCompleja::Sincronizar(bool sincronizar)
 
 void GVistaCompleja::Sincronizar(const TipoListaVista2D& lista)
 {
-	//si esta reproduciendose se para
-	Stop();
 	//se suscribe a los eventos de los brothers
 	for(TipoListaVista2D::const_iterator it = lista.begin(); it!= lista.end(); ++it){
 		if((*it) != IVista){
@@ -1275,7 +1038,7 @@ void GVistaCompleja::Sincronizar(const TipoListaVista2D& lista)
 			m_ListaSincronizacion.push_back((*it));
 		}
 	}
-	m_pBarraDerecha->ToggleTool(ID_BOTON_SINCRONIZAR,true);
+	m_pBarraDerecha->ForceToggleTool(ID_BOTON_SINCRONIZAR,true);
 	m_pBarraDerecha->Refresh();
 }
 
@@ -1290,14 +1053,11 @@ void GVistaCompleja::DesSincronizar(){
 	}
 	m_ListaSincronizacion.clear();
 
-	m_pBarraCine->Enable(true);
-	m_pBarraCine->Refresh();
-
 	//dessincronizamos
 	AtencionPrimaria::Events::EventoSincronizacion* evento = new AtencionPrimaria::Events::EventoSincronizacion(IVista,AtencionPrimaria::Events::EventoSincronizacion::Dessincronizar);
 	GNC::GCS::IEntorno::Instance()->GetControladorEventos()->ProcesarEvento(evento);
 
-	m_pBarraDerecha->ToggleTool(ID_BOTON_SINCRONIZAR,false);
+	m_pBarraDerecha->ForceToggleTool(ID_BOTON_SINCRONIZAR,false);
 	m_pBarraDerecha->Refresh();
 }
 
@@ -1447,19 +1207,13 @@ void GVistaCompleja::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
 				if(pEvt!=NULL){
 					if(pEvt->GetTipoEvento() == AtencionPrimaria::Events::EventoSincronizacion::Scroll){
 						GoToSlice(pEvt->GetPosicion(),pEvt->EsRelativa(),false);
-					} else if (pEvt->GetTipoEvento() == AtencionPrimaria::Events::EventoSincronizacion::Play) {
-						m_pBarraCine->Enable(false);
-						m_pBarraCine->Refresh();
-					} else if (pEvt->GetTipoEvento() == AtencionPrimaria::Events::EventoSincronizacion::Stop) {
-						m_pBarraCine->Enable(true);
-						m_pBarraCine->Refresh();
 					} else if (pEvt->GetTipoEvento() == AtencionPrimaria::Events::EventoSincronizacion::Dessincronizar) {
 						for(TipoListaVista2D::iterator it = m_ListaSincronizacion.begin(); it!= m_ListaSincronizacion.end(); ++it){
 							if((*it) == pEvt->GetVista()){
 								GNC::GCS::IEntorno::Instance()->GetControladorEventos()->DesRegistrar(this,*pEvt);
 								m_ListaSincronizacion.erase(it);
 								if(m_ListaSincronizacion.empty()){
-									m_pBarraDerecha->ToggleTool(ID_BOTON_SINCRONIZAR,false);
+									m_pBarraDerecha->ForceToggleTool(ID_BOTON_SINCRONIZAR,false);
 									m_pBarraDerecha->Refresh();
 								}
 								return;
@@ -1576,52 +1330,3 @@ void GVistaCompleja::ProcesarEvento(GNC::GCS::Events::IEvent *evt)
 			break;
 	}
 }
-
-/*TODO
-void GVistaCompleja::GetImage(GNC::GCS::IContratoExportacionImages::ImageType::Pointer& img, int index, bool conWidgets, const GNC::GCS::Vector& size)
-{
-	if (!IVista->VisualizatorStudy->Viewer->IsInstalledAndInitialized())
-		return ;
-
-	GNKVisualizator::ImprimeVistaSimple imprimeVistaSimple(m_pManager, IVista->VisualizatorStudy, index);
-
-	if(IVista->VisualizatorStudy->Viewer->GetNumberOfComponents() == 3) {
-		imprimeVistaSimple.PrintImageRGB(img,conWidgets, size);
-	} else {
-		vtkScalarsToColors* pTabla = GetLookupTable();
-		if(pTabla != NULL) {
-			imprimeVistaSimple.PrintImage(img, conWidgets, pTabla, size);
-		}
-	}
-}*/
-//
-//void GVistaCompleja::SetReconstructionMode(GNKVisualizator::Reconstruction::ReconstructionMode mode)
-//{
-//
-//	switch (mode) {
-//		case GNKVisualizator::Reconstruction::RM_SurfaceRendering:
-//			{
-//				typedef MedicalViewer::Reconstruction::GUI::wxSurfaceRendering TReconstructionWin;
-//				TReconstructionWin* win = new TReconstructionWin(this, GNKVisualizator::IReconstructionContract::Estudio);
-//				win->Show(true);				
-//			}
-//			break;
-//		case GNKVisualizator::Reconstruction::RM_VolumeRendering:
-//			{
-//				typedef MedicalViewer::Reconstruction::GUI::wxVolumeRendering TReconstructionWin;
-//				TReconstructionWin* win = new TReconstructionWin(this, GNKVisualizator::IReconstructionContract::Estudio, GetViewerActivo()->GetWindow(), GetViewerActivo()->GetLevel());
-//				win->Show(true);
-//			}
-//			break;
-//		case GNKVisualizator::Reconstruction::RM_OrthogonalMPR:
-//		case GNKVisualizator::Reconstruction::RM_MIP3D:
-//		case GNKVisualizator::Reconstruction::RM_3D_Endoscopy:
-//		case GNKVisualizator::Reconstruction::RM_MaxMode:
-//			wxMessageBox(_("Reconstruction mode not implemented:\n"), _("Error"), wxICON_ERROR);
-//			break;
-//		default:
-//			wxMessageBox(_("Reconstruction mode not supported:\n"), _("Error"), wxICON_ERROR);
-//			break;
-//			
-//	}	
-//}
