@@ -105,32 +105,20 @@ public:
 	virtual void OnPaint(wxPaintEvent& evt);
 
 	void OnMenuVerClick(wxCommandEvent& event);
-	void OnMenuCineClick(wxAuiToolBarEvent& evt);
 	void OnInvertColorMap(wxCommandEvent &event);
 
 	void ActualizarMaxMinSlider();
 
 	void OnFocus(wxChildFocusEvent &event);
-
-	void SetPeriodo(int milisegundos);
-
+	
 	void OnSize(wxSizeEvent &event);
 
 	void OnZSliderScroll (wxScrollEvent& event);
 
-	void OnKeyDown( wxKeyEvent& event );
+	void OnChar( wxKeyEvent& event );
 
 	void OnMouseWheel( wxMouseEvent& event );
 
-	void OnPlayStopClick(wxCommandEvent &event);
-
-	void Play();
-	void Stop();
-
-	void OnBucleClick(wxCommandEvent &event);
-
-	void OnTimer();
-
 	void OnSincronizarClick(wxCommandEvent &event);
 
 	void Sincronizar(bool sincronizar);
@@ -162,16 +150,12 @@ public:
 	GNC::GCS::IVista* GetView();
 protected:
 	GNKVisualizator::Vista2D*            IVista;
-	TimerPlay*                           m_playTimer;
 	BarraHerramientasBotones*            m_pBarraIzquierda;
-	BarraHerramientasBotones*            m_pBarraCine;
 	BarraHerramientasBotones*            m_pBarraDerecha;
 
 	int                                  m_orientacion;
 	TipoListaVista2D                     m_ListaSincronizacion;
 	int m_posicion;
-	bool                                 m_ReproducirBucle;
-	int                                  m_PeriodoMs;
 	typedef std::vector<GVistaSimple*>   TListaGVistasSimples;
 	TListaGVistasSimples                 m_VistasSimples;
 	///widgets
