@@ -146,7 +146,7 @@ GVistaSimple::GVistaSimple(GNKVisualizator::Vista2D* pIVista, wxWindow* parent)
 	GNC::GCS::IEntorno::Instance()->GetControladorEventos()->Registrar(this, evtChange);
 
 	this->Connect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GVistaSimple::OnFocus),NULL,this);
-	ViewInteractor2D->Connect(wxEVT_KEY_DOWN,wxKeyEventHandler(GVistaSimple::OnKeyDown),NULL,this);
+	ViewInteractor2D->Connect(wxEVT_KEY_DOWN,wxKeyEventHandler(GVistaSimple::OnChar),NULL,this);
 	this->Layout();
 }
 
@@ -157,7 +157,7 @@ GVistaSimple::~GVistaSimple() {
 		m_pObserverVTK = NULL;
 	}
 	this->Disconnect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GVistaSimple::OnFocus),NULL,this);
-	ViewInteractor2D->Disconnect(wxEVT_KEY_DOWN,wxKeyEventHandler(GVistaSimple::OnKeyDown),NULL,this);
+	ViewInteractor2D->Disconnect(wxEVT_KEY_DOWN,wxKeyEventHandler(GVistaSimple::OnChar),NULL,this);
 
 	this->Disconnect( wxEVT_SIZE, wxSizeEventHandler( GVistaSimple::OnSize ) );
 
@@ -268,9 +268,9 @@ void GVistaSimple::ResetTimeInstant()
 	ViewImage2D->SetTindex(0);
 }
 
-void GVistaSimple::OnKeyDown( wxKeyEvent& event )
+void GVistaSimple::OnChar( wxKeyEvent& event )
 {
-	event.ResumePropagation(2);
+	event.ResumePropagation(3);
 	event.Skip(true);
 }
 
