@@ -68,24 +68,10 @@ public:
 
 	void ResetTimeInstant();
 
-	void SetPeriodo(int milisegundos);
-
-	void OnKeyDown( wxKeyEvent& event );
+	void OnChar( wxKeyEvent& event );
 
 	void OnMouseWheel( wxMouseEvent& event );
-
-	void OnPlayClick(wxCommandEvent &event);
-
-	void OnStopClick(wxCommandEvent &event);
-
-	void OnBucleClick(wxCommandEvent &event);
-
-	void OnTimer();
-
-	void OnSincronizarClick(wxCommandEvent &event);
-
-	void OnDessincronizarClick(wxCommandEvent &event);
-
+	
 	void OnTimeInstantChanged(wxScrollEvent& event);
 
 	void GoToTSlice(int posicion, bool relativa =  true);
@@ -93,12 +79,7 @@ public:
 	void GoToSlice(int posicion, bool relativa =  true, bool propagar = true);
 
 	void ActualizarTSlider();
-
-	typedef std::list<GNKVisualizator::Vista2D*> TipoListaVista2D;
-	void Sincronizar(TipoListaVista2D lista);
-	void DesSincronizar();
-	bool IsSincronized();
-
+	
    //endregion
 
 	//region "Interfaz de impresion de overlays de widgets"
