@@ -18,7 +18,7 @@
 #include <eventos/modificacionwidget.h>
 #include <eventos/render.h>
 #include <wx/pen.h>
-#include <wx/aui/auibar.h>
+#include <wx/wxginkgotoolbar.h>
 #include <api/iannotator.h>
 #include <wx/ginkgostyle/ginkgostyle.h>
 
@@ -109,30 +109,12 @@ namespace GNKVisualizator
 		protected:
 			GWaveformView* GView;
 		};
-		//esta clase sirve para las barras de herramientas de abajo
-		class GWaveformViewButtonBar:public wxAuiToolBar{
-		public:
-			GWaveformViewButtonBar(wxWindow* pParent, const wxColor& color = wxColor(0x40, 0x40, 0x40)): wxAuiToolBar(pParent,wxID_ANY, wxDefaultPosition, wxDefaultSize, wxAUI_TB_DEFAULT_STYLE)
-			{
-				SetToolBitmapSize(wxSize(16,16));
-				AUI_NAMESPACE wxAuiDefaultToolBarArt* pToolArt= new AUI_NAMESPACE wxAuiDefaultToolBarArt();
-		#if defined(USE_PATCHED_LIBS) && !defined(__WXOSX__)
-				pToolArt->SetBaseColor(color);
-		#endif
-				SetArtProvider(pToolArt);
-			}
-
-			~GWaveformViewButtonBar()
-			{
-			}
-		};
-		
+				
 		/* Constructor */
 		GWaveformView::GWaveformView(GNKVisualizator::WaveFormView* pView) : GWaveformViewBase(pView->GetEstudio()->ParentWindow),
 				Delegate(new GWaveformViewDelegate(this)),
 				AnnotatorDelegate(new GWaveformAnnotatorDelegate(this, pView))
 		{
-			Freeze();
 			View = pView;
 			WECG = NULL;
 
@@ -170,7 +152,9 @@ namespace GNKVisualizator
 			pToolBar->AddTool(HCore_Marcado, (GNC::GCS::IWidgetsContract*) Delegate);
 			//view menu...
 			pToolBar->AddTool(HCore_CornerAnnotations, (GNC::GCS::IWidgetsContract*) Delegate);
+			#if !defined(__WXGTK__)
 			pToolBar->AddTool(HCore_DetachWindow, (GNC::GCS::IViewContract*) View);
+			#endif
 			pToolBar->AddTool(HCore_MetricGrid, (GNC::GCS::IWidgetsContract*) Delegate);
 			pToolBar->AddTool(HCore_Reset, (GNC::GCS::IWidgetsContract*) Delegate);
 
@@ -196,7 +180,7 @@ namespace GNKVisualizator
 			GNC::GCS::Events::EventoModificacionWidget ev3(View);
 			GNC::GCS::Events::EventoRender ev4(View);
 
-			m_pButtonBar = new GWaveformViewButtonBar(m_pManipulationPanel);
+			m_pButtonBar = new wxGinkgoToolBar(m_pManipulationPanel, wxColour(0x40, 0x40, 0x40));
 			m_pButtonBar->AddTool(ID_BUTTON_METADATA,_("Show/Hide metadata"),GNKVisualizator::ResourcesManager::ToolIcons::GetIcoECGMetadata(),_("Show/Hide metadata"));
 			m_pButtonBar->Connect(ID_BUTTON_METADATA,wxEVT_COMMAND_TOOL_CLICKED, wxCommandEventHandler( GWaveformView::OnShowHideMetadata),NULL,this);
 
@@ -209,6 +193,9 @@ namespace GNKVisualizator
 
 			m_pButtonBar->Realize();
 			m_pSizerRight->Add(m_pButtonBar,0, wxALIGN_CENTER_VERTICAL|wxEXPAND,0);
+
+			//connect key events..
+			pToolBar->ConnectKeyEvents(this);
 			
 			GNC::GCS::IEntorno::Instance()->GetControladorEventos()->Registrar(this, ev2);
 			GNC::GCS::IEntorno::Instance()->GetControladorEventos()->Registrar(this, ev3);
@@ -222,7 +209,6 @@ namespace GNKVisualizator
 			this->Connect(wxEVT_CHILD_FOCUS, wxChildFocusEventHandler(GWaveformView::OnFocus),NULL,this);
 			
 			Layout();
-			Thaw();
 		}
 
 		GWaveformView::~GWaveformView()
