@@ -19,14 +19,13 @@
 #include "visualizatorviews.h"
 
 class vtkGinkgoImageViewer;
-
+class wxGinkgoToolBar;
 namespace GNKVisualizator{
 	namespace Widgets {
 		class WECG;
 	}
 	class WaveFormView;
 	namespace GUI {
-		class GWaveformViewButtonBar;
 		class GWaveformViewDelegate;
 		class GWaveformAnnotatorDelegate;
 			
@@ -67,7 +66,7 @@ namespace GNKVisualizator{
 
 			GNKVisualizator::WaveFormView* View;
 			GNKVisualizator::Widgets::WECG* WECG;
-			GWaveformViewButtonBar* m_pButtonBar;
+			wxGinkgoToolBar* m_pButtonBar;
 			
 			GNC::GCS::IWidgetsManager* m_pManager;
 			GNC::GCS::Ptr<GWaveformViewDelegate> Delegate;
